@@ -160,6 +160,9 @@
 /* Define to 1 if you have ospeed, but it is not defined in termcap.h */
 #undef MUST_DEFINE_OSPEED
 
+/* Define to 1 if tgetent() accepts NULL as a buffer */
+#undef TGETENT_ACCEPTS_NULL
+
 /* Define to 1 if you use POSIX style signal handling */
 #undef POSIX_SIGNALS
  
