@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #ifdef MHRC
 # include <pwd.h>
@@ -15,21 +15,20 @@
 #define nmhetcdir(file) NMHETCDIR#file
 #define nmhlibdir(file) NMHLIBDIR#file
 
-static char lpath[BUFSIZ];
-
 
 char *
-libpath (char *file)
+etcpath (char *file)
 {
+    static char epath[BUFSIZ];
     char *cp;
 #ifdef MHRC
     char *pp;
     struct passwd *pw;
-#endif /* MHRC */
+#endif
 
 #ifdef MHRC
     m_getdefs();
-#endif /* MHRC */
+#endif
 
     switch (*file) {
 	case '/': 
@@ -50,23 +49,24 @@ libpath (char *file)
 		    goto try_it;
 		}
 
-	    sprintf (lpath, "%s/%s", pp, cp ? cp : "");
+	    sprintf (epath, "%s/%s", pp, cp ? cp : "");
 	    if (cp)
 		*--cp = '/';
 
-	    if (access (lpath, 04) != NOTOK)
-		return lpath;	/* else fall */
+	    if (access (epath, R_OK) != NOTOK)
+		return epath;	/* else fall */
     try_it: ;
 #endif /* MHRC */
 
 	default: 
-	    if (access ((cp = m_mailpath (file)), 04) != NOTOK)
+	    if (access ((cp = m_mailpath (file)), R_OK) != NOTOK)
 		return cp;
     }
-    sprintf (lpath, nmhetcdir(/%s), file);
-    return (access (lpath, 04) != NOTOK ? lpath : file);
+    sprintf (epath, nmhetcdir(/%s), file);
+    return (access (epath, R_OK) != NOTOK ? epath : file);
 }
 
+
 /* 
  * Standard yes/no switches structure
  */
@@ -204,6 +204,11 @@ char *postproc = nmhlibdir (/spost);
 char *postproc = nmhlibdir (/post);
 #endif /* BERK */
 
+/*
+ * This is program is called by slocal to handle the `+' action.
+ */
+char *rcvstoreproc = nmhlibdir (/rcvstore);
+
 /* 
  * This program is called to remove a folder.  
  */
