@@ -1,5 +1,9 @@
 
-/* dropsbr.h - definitions for maildrop-style files */
+/*
+ * dropsbr.h -- definitions for maildrop-style files
+ *
+ * $Id$
+ */
 
 /*
  * A file which is formatted like a maildrop may have a corresponding map
@@ -26,15 +30,26 @@
 #define	DRVRSN 3
 
 struct drop {
-    int     d_id;
-    int	    d_size;
-    long    d_start;
-    long    d_stop;
+    int  d_id;
+    int	 d_size;
+    long d_start;
+    long d_stop;
 };
 
-int map_chk(), map_read(), map_write();
-char *map_name();
+/*
+ * prototypes
+ */
+int mbx_mmdf(void);
+int mbx_uucp(void);
+int mbx_open (char *, uid_t, gid_t, mode_t);
+int mbx_Xopen (char *, uid_t, gid_t, mode_t, int *);
+int mbx_read (FILE *, long, struct drop **, int);
+int mbx_write(char *, int, FILE *, int, long, long, long, int, int);
+int mbx_copy (char *, int, int, int, char *, int);
+int mbx_size (int, long, long);
+int mbx_close (char *, int);
+char *map_name (char *);
+int map_read (char *, long, struct drop **, int);
+int map_write (char *, int, int, long, long, long, long, int, int);
+int map_chk (char *, int, struct drop *, long, int);
 
-int mbx_mmdf(), mbx_uucp();
-int mbx_open(), mbx_Xopen(), mbx_copy(), mbx_size(), mbx_close();
-int mbx_read(), mbx_write();
