@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "nmh.h"
+#include <h/nmh.h>
 
 /*
  * Well-used constants
@@ -55,7 +55,7 @@ extern struct swit anoyes[];	/* standard yes/no switches */
 
 /*
  * msgstats[] is a int, so we have 16 or 32 bits to work
- * with.  The first 5 are for standard MH message flags,
+ * with.  The first 5 are for standard nmh message flags,
  * this leaves us 11 (or 27) for user-defined attributes.
  * Of these, 1 is reserved for future internal use, so
  * this leaves users 10 (or 26).
@@ -63,21 +63,25 @@ extern struct swit anoyes[];	/* standard yes/no switches */
 #define	NUMATTRS  ((sizeof(int) * Nbby) - 6)
 
 /* folder attributes */
-#define READONLY  0x01		/* No write access to folder    */
-#define	SEQMOD	  0x02		/* folder's sequences modifed   */
-#define	MHPATH	  0x04		/* mhpath-style folder handling */
-#define	OTHERS	  0x08		/* folder has other files	*/
-#define	MODIFIED  0x10		/* msh in-core folder modified  */
+#define READONLY  (1<<0)	/* No write access to folder    */
+#define	SEQMOD	  (1<<1)	/* folder's sequences modifed   */
+#define	MHPATH	  (1<<2)	/* mhpath-style folder handling */
+#define	OTHERS	  (1<<3)	/* folder has other files	*/
+#define	MODIFIED  (1<<4)	/* msh in-core folder modified  */
 
 #define	FBITS "\020\01READONLY\02SEQMOD\03MHPATH\04OTHERS\05MODIFIED"
 
 /* messages attributes */
-#define EXISTS        0x0001	/* exists                  */
-#define DELETED       0x0002	/* deleted                 */
-#define SELECTED      0x0004	/* selected for use        */
-#define SELECT_EMPTY  0x0008	/* mhpath "new"            */
-#define	UNSEEN        0x0010	/* inc/show "unseen"       */
-#define	FFATTRSLOT    5		/* user-defined attributes */
+#define EXISTS        (1<<0)	/* exists            */
+#define DELETED       (1<<1)	/* deleted           */
+#define SELECTED      (1<<2)	/* selected for use  */
+#define SELECT_EMPTY  (1<<3)	/* mhpath "new"      */
+#define	UNSEEN        (1<<4)	/* inc/show "unseen" */
+
+/*
+ * first free attribute slot for user-defined attributes
+ */
+#define	FFATTRSLOT  5
 
 /*
  * first free slot is (1 << 5) or 0x20
@@ -195,8 +199,8 @@ extern struct node *m_defs;	/* profile/context structure  */
 
 /*
  * These standard strings are defined in config.c.  They are the
- * only system-dependent parameters in MH, and thus by redefining
- * their values and reloading the various modules, MH will run
+ * only system-dependent parameters in nmh, and thus by redefining
+ * their values and reloading the various modules, nmh will run
  * on any system.
  */
 extern char *components;
@@ -230,6 +234,7 @@ extern char *postproc;
 extern char *pfolder;
 extern char *psequence;
 extern char *rcvdistcomps;
+extern char *rcvstoreproc;
 extern char *replcomps;
 extern char *rmfproc;
 extern char *rmmproc;
@@ -243,5 +248,5 @@ extern char *vmhproc;
 extern char *whatnowproc;
 extern char *whomproc;
 
-#include "prototypes.h"
+#include <h/prototypes.h>
 
