@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../config.h"
+#include <config.h>
 
 /*
  * The type for a signal handler
