@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../../h/mh.h"
+#include <h/mh.h>
 #include "smail.h"
-#include "../../zotnet/mts/mts.h"
+#include <zotnet/mts/mts.h>
 #include <signal.h>
 
 /*
@@ -642,8 +642,6 @@ sm_end (int type)
 
 #ifdef MPOP
 #ifdef SMTP
-#include <sys/types.h>
-#include <sys/stat.h>
 
 int
 sm_bulk (char *file)
