@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 void
 cpydata (int in, int out, char *ifile, char *ofile)
