@@ -5,11 +5,11 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
-#include "../zotnet/tws/tws.h"
-#include "../h/fmtcompile.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
+#include <zotnet/tws/tws.h>
+#include <h/fmtcompile.h>
 
 static struct format *formatvec;	/* array to hold formats */
 static struct format *next_fp;		/* next free format slot */
