@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
 
 static char *buf;		/* our current working buffer */
 static char *bufend;		/* end of working buffer */
