@@ -5,6 +5,6 @@
  * $Id$
  */
 
-#include "../h/addrsbr.h"
+#include <h/addrsbr.h>
 
 int fmt_norm = AD_NAME;
