@@ -5,16 +5,16 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
-#include "../zotnet/tws/tws.h"
-#include "../h/fmtcompile.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
+#include <zotnet/tws/tws.h>
+#include <h/fmtcompile.h>
 
 #define	NFMTS	MAXARGS
 #define QUOTE '\\'
 
-static char  *formats = 0;
+static char *formats = 0;
 extern char *formataddr ();	/* hook for custom address formatting */
 
 #ifdef LBL
@@ -45,7 +45,7 @@ new_fs (char *form, char *format, char *def)
 	free (formats);
 
     if (form) {
-	if ((fp = fopen (libpath (form), "r")) == NULL)
+	if ((fp = fopen (etcpath (form), "r")) == NULL)
 	    adios (form, "unable to open format file");
 
 	if (fstat (fileno (fp), &st) == NOTOK)
@@ -59,7 +59,7 @@ new_fs (char *form, char *format, char *def)
 
 	formats[st.st_size] = '\0';
 
-	(void) fclose (fp);
+	fclose (fp);
     }
     else {
 	formats = getcpy (format ? format : def);
@@ -300,9 +300,9 @@ get_x400_friendly (char *mbox, char *buffer)
 	return NULL;
 
     if (get_x400_comp (mbox, "/G=", given))
-	(void) sprintf (buffer, "%s %s", given, surname);
+	sprintf (buffer, "%s %s", given, surname);
     else
-	(void) strcpy (buffer, surname);
+	strcpy (buffer, surname);
 
     return buffer;
 }
@@ -317,28 +317,28 @@ get_x400_comp (char *mbox, char *key, char *buffer)
 	    || !(cp = strchr(mbox += idx + strlen (key), '/')))
 	return 0;
 
-    (void) sprintf (buffer, "%*.*s", cp - mbox, cp - mbox, mbox);
+    sprintf (buffer, "%*.*s", cp - mbox, cp - mbox, mbox);
     return 1;
 }
 
 struct format *
 fmtscan (struct format *format, char *scanl, int width, int *dat)
 {
-    register char	*cp = scanl;
-    register char	*ep = scanl + width - 1;
+    register char *cp = scanl;
+    register char *ep = scanl + width - 1;
     register struct format *fmt = format;
-    register char	*str = NULL;
-    register int	value = 0;
-    register char	*sp;
-    register int	i;
-    register int	c;
+    register char *str = NULL;
+    register int value = 0;
+    register char *sp;
+    register int i;
+    register int c;
     register struct comp *comp;
     register struct tws *tws;
     register struct mailname *mn;
     int ljust;
     long l;
-    char        *savestr;
-    char	buffer[BUFSIZ];
+    char *savestr;
+    char buffer[BUFSIZ];
 
     while (cp < ep) {
 	switch (fmt->f_type) {
@@ -497,7 +497,7 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
 	    if (str) {
 		    register char *xp;
 
-		    (void) strcpy(buffer, str);
+		    strcpy(buffer, str);
 		    str = buffer;
 		    while (isspace(*str))
 			    str++;
@@ -689,7 +689,7 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
 		goto unfriendly;
 	    if ((str = mn->m_pers) == NULL)
 	        if ((str = mn->m_note)) {
-	            (void) strcpy (buffer, str);
+	            strcpy (buffer, str);
 	            str = buffer;
 	            if (*str == '(')
 	            	str++;
@@ -709,14 +709,12 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
 			str = mn->m_mbox;
 			break;
 		    case UUCPHOST:
-			(void) sprintf (buffer, "%s!%s",
-					mn->m_host, mn->m_mbox);
+			sprintf (buffer, "%s!%s", mn->m_host, mn->m_mbox);
 			str = buffer;
 			break;
 		    default:
 			if (mn->m_mbox) {
-			    (void) sprintf (buffer, "%s@%s",
-					    mn->m_mbox, mn->m_host);
+			    sprintf (buffer, "%s@%s", mn->m_mbox, mn->m_host);
 			    str= buffer;
 			}
 			else
@@ -851,7 +849,7 @@ fmtscan (struct format *format, char *scanl, int width, int *dat)
 	     * disturb string or value registers.
 	     */
 	    if (fmt_current_folder)
-		    (void)m_seqadd(fmt_current_folder, fmt->f_text, dat[0], -1);
+		    m_seqadd(fmt_current_folder, fmt->f_text, dat[0], -1);
 #endif
 	    break;
 	}
