@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 /*
  * PLEASE be non-trivial...
@@ -17,7 +17,7 @@ struct info {
     int stats;
 };
 
-static int len=0;
+static int len = 0;
 static struct info *head;
 
 /*
@@ -37,21 +37,20 @@ m_gmsg (char *name)
     DIR *dd;
     struct stat st;
 
-    if ((dd = opendir (name = m_mailpath (name))) == NULL) {
+    if (!(dd = opendir (name = m_mailpath (name)))) {
 	free (name);
 	return NULL;
     }
     fstat (dd->dd_fd, &st);
 
-    mp = (struct msgs *) malloc (MHSIZE (mp, 0, 0));
-    if (mp == NULL)
+    if (!(mp = (struct msgs *) malloc (MHSIZE (mp, 0, 0))))
 	adios (NULL, "unable to allocate folder storage");
     mp->lowmsg = mp->hghmsg = mp->nummsg = 0;
     mp->curmsg = 0;
     mp->lowsel = mp->hghsel = mp->numsel = 0;
     mp->foldpath = name;
     mp->msgflags = 0;
-    if (st.st_uid != getuid () || access (name, 02) == NOTOK)
+    if (st.st_uid != getuid () || access (name, W_OK) == NOTOK)
 	mp->msgflags |= READONLY;
     j = strlen(BACKUP_PREFIX);
     if (!head)
@@ -103,12 +102,12 @@ m_gmsg (char *name)
 #endif /* notdef */
 		    continue;
 
-#ifdef	MHE
+#ifdef MHE
 		case '+': 
 		    continue;
 #endif /* MHE */
 
-#ifdef	UCI
+#ifdef UCI
 		case '_': 
 		case '#': 
 		    continue;
@@ -240,7 +239,7 @@ m_setatr (struct msgs *mp, char *name, char *field)
 	return NOTOK;
     }
 
-    if (mp->msgattrs[i] == NULL) {
+    if (!mp->msgattrs[i]) {
 	mp->msgattrs[i] = name;
 	mp->msgattrs[i + 1] = NULL;
     }
