@@ -5,40 +5,41 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
-static struct procs {
-	char    *procname;
-	char    **procnaddr;
-} procs [] = {
-	{ "context",	&context	},
-	{ "mh-sequences",
-			&mh_seq		},
-	{ "faceproc",	&faceproc	},
-	{ "fileproc",   &fileproc       },
-	{ "incproc",	&incproc	},
-    	{ "installproc",&installproc	},
-	{ "lproc",      &lproc          },
-	{ "mailproc",	&mailproc	},
-	{ "mhlproc",	&mhlproc	},
-	{ "moreproc",	&moreproc	},
-	{ "mshproc",	&mshproc	},
-	{ "packproc",	&packproc	},
-	{ "postproc",   &postproc       },
-	{ "rmfproc",	&rmfproc	},
-	{ "rmmproc",	&rmmproc	},
-	{ "sendproc",   &sendproc       },
-	{ "showproc",   &showproc       },
-	{ "slocalproc", &slocalproc     },
-	{ "vmhproc",    &vmhproc        },
-	{ "whatnowproc",
-			&whatnowproc	},
-	{ "whomproc",	&whomproc	},
-	{ NULL,         NULL            }
+struct procstr {
+    char *procname;
+    char **procnaddr;
+};
+
+static struct procstr procs[] = {
+    { "context",      &context },
+    { "mh-sequences", &mh_seq },
+    { "faceproc",     &faceproc },
+    { "fileproc",     &fileproc },
+    { "incproc",      &incproc },
+    { "installproc",  &installproc },
+    { "lproc",        &lproc },
+    { "mailproc",     &mailproc },
+    { "mhlproc",      &mhlproc },
+    { "moreproc",     &moreproc },
+    { "mshproc",      &mshproc },
+    { "packproc",     &packproc },
+    { "postproc",     &postproc },
+    { "rmfproc",      &rmfproc },
+    { "rmmproc",      &rmmproc },
+    { "sendproc",     &sendproc },
+    { "showproc",     &showproc },
+    { "slocalproc",   &slocalproc },
+    { "vmhproc",      &vmhproc },
+    { "whatnowproc",  &whatnowproc },
+    { "whomproc",     &whomproc },
+    { NULL,           NULL }
 };
 
 static struct node **opp = NULL;
 
+
 void
 m_readefs (struct node **npp, FILE *ib, char *file, int ctx)
 {
@@ -46,7 +47,7 @@ m_readefs (struct node **npp, FILE *ib, char *file, int ctx)
     register char *cp;
     char name[NAMESZ], field[BUFSIZ];
     register struct node *np;
-    register struct procs *ps;
+    register struct procstr *ps;
 
     if (npp == NULL && (npp = opp) == NULL) {
 	admonish (NULL, "bug: m_readefs called but pump not primed");
@@ -58,8 +59,8 @@ m_readefs (struct node **npp, FILE *ib, char *file, int ctx)
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
-		np = (struct node *) malloc (sizeof *np);
-		if (np == NULL)
+		np = (struct node *) malloc (sizeof(*np));
+		if (!np)
 		    adios (NULL, "unable to allocate profile storage");
 		*npp = np;
 		*(npp = &np->n_next) = NULL;
