@@ -5,11 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
-#define	MAXPATHLEN 1024
-
-static char curwd[MAXPATHLEN];
+static char curwd[PATH_MAX];
 
 
 char *
@@ -17,9 +15,9 @@ pwd(void)
 {
     register char *cp;
 
-    if (getcwd (curwd, MAXPATHLEN) == NULL) {
+    if (!getcwd (curwd, PATH_MAX)) {
 	admonish (NULL, "unable to determine working directory");
-	if (mypath == NULL || *mypath == 0
+	if (!mypath || !*mypath
 		|| (strcpy (curwd, mypath), chdir (curwd)) == NOTOK) {
 	    strcpy (curwd, "/");
 	    chdir (curwd);
@@ -43,14 +41,11 @@ pwd(void)
 int
 getwd(char *cwd)
 {
-    int     found;
-    char    tmp1[BUFSIZ],
-            tmp2[BUFSIZ];
-    struct stat st1,
-                st2,
-                root;
+    int found;
+    char tmp1[BUFSIZ], tmp2[BUFSIZ];
+    struct stat st1, st2, root;
     register struct direct *dp;
-    register    DIR * dd;
+    register DIR *dd;
 
     strcpy (cwd, "/");
     stat ("/", &root);
