@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/aliasbr.h"
+#include <h/mh.h>
+#include <h/aliasbr.h>
 #include <grp.h>
 #include <pwd.h>
 
@@ -138,7 +138,7 @@ alias (char *file)
 
     if (*file != '/'
 	    && (strncmp (file, "./", 2) && strncmp (file, "../", 3)))
-	file = libpath (file);
+	file = etcpath (file);
     if ((fp = fopen (file, "r")) == NULL) {
 	akerrst = file;
 	return AK_NOFILE;
@@ -319,12 +319,12 @@ addfile (struct aka *ak, char *file)
     char buffer[BUFSIZ];
     register FILE *fp;
 
-    if ((fp = fopen (libpath (file), "r")) == NULL) {
+    if (!(fp = fopen (etcpath (file), "r"))) {
 	akerrst = file;
 	return 0;
     }
 
-    while (fgets (buffer, sizeof buffer, fp) != NULL)
+    while (fgets (buffer, sizeof buffer, fp))
 	while (cp = getalias (buffer))
 	    add_aka (ak, cp);
 
