@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <zotnet/tws/tws.h>
 #include <errno.h>
 
 extern int  errno;
