@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
 
 #define	NADDRS	100
 
@@ -38,6 +38,11 @@ static struct format *fmt;
 
 static int dat[5];
 
+/*
+ * prototypes
+ */
+int sc_width (void);  /* from termsbr.c */
+
 /*
  * static prototypes
  */
@@ -66,7 +71,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
