@@ -5,13 +5,13 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
-#include "../zotnet/bboards/bboards.h"
+#include <h/mh.h>
+#include <h/signals.h>
+#include <zotnet/bboards/bboards.h>
 
 #ifdef BPOP
-# include "../zotnet/mts.h"
-#endif /* BPOP */
+# include <zotnet/mts.h>
+#endif
 
 #include <errno.h>
 #include <signal.h>
@@ -24,19 +24,14 @@
 # undef SIGTSTP
 #endif ridge
 
-#include <sys/types.h>
-#include <sys/stat.h>
-
 #ifdef SIGTSTP
 # include <sys/wait.h>
 # include <sys/time.h>
 # include <sys/resource.h>
 #endif SIGTSTP
 
-#define	RCFILE	".bbrc"
-
-#define	NBB	100
-
+#define	RCFILE ".bbrc"
+#define	NBB 100
 
 static struct swit switches[] = {
 #define	TOPICSW              0
@@ -67,40 +62,32 @@ static struct swit switches[] = {
     { "file BBoardsfile", 4 },
 
 #define	USERSW              13
-    { "user BBoardsuser",
 #ifndef	NNTP
-	                  4
+    { "user BBoardsuser", 4 },
 #else	NNTP
-	                 -4
+    { "user BBoardsuser", -4 },
 #endif	NNTP
-                            },
 
 #define	HOSTSW              14
-    { "host host",
 #ifndef	BPOP
-                   -4
+    { "host host", -4 },
 #else	BPOP
-                    4
+    { "host host", 4 },
 #endif	BPOP
-                      },
 
 #define	RPOPSW              15
-    { "rpop",
 #ifndef	RPOP
-	      -4
+    { "rpop", -4 },
 #else	RPOP
-	       4
+    { "rpop", 4 },
 #endif	RPOP
-                 },
 
 #define	NRPOPSW             16
-    { "norpop",
 #ifndef	RPOP
-	        -6
+    { "norpop", -6 },
 #else	RPOP
-	         6
+    { "norpop", 6 },
 #endif	RPOP
-                   },
 
 #define VERSIONSW           17
     { "version", 0 },
@@ -1254,7 +1241,7 @@ struct bboard *getbbvis () {
 
     while (bb = getbbent ())
 	if (!(bb->bb_flags & BB_INVIS)
-		&& (access (bb->bb_file, 04) != NOTOK || errno != EACCES))
+		&& (access (bb->bb_file, R_OK) != NOTOK || errno != EACCES))
 	    break;
 
     return bb;
