@@ -5,9 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/local.h"
-#include "../zotnet/bboards.h"
+#include <h/mh.h>
+#include <zotnet/bboards.h>
 #include <pwd.h>
 
 static struct swit switches[] = {
@@ -173,8 +172,8 @@ process () {
     }
 }
 
-int     check_folder (folder)
-char   *folder;
+int
+check_folder (char *folder)
 {
     char   *maildir;
     struct stat st;
@@ -185,7 +184,7 @@ char   *folder;
     if (stat (maildir, &st) == NOTOK)
 	return 0;
 
-    if ((st.st_mode & S_IFMT) != S_IFDIR)
+    if (!S_ISDIR(st.st_mode))
 	adios (NULL, "not a directory '%s'", maildir);
     check_mode (maildir, (st.st_mode | 0555) & 0777);
 
