@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/aliasbr.h"
-#include "../zotnet/mts/mts.h"
+#include <h/mh.h>
+#include <h/aliasbr.h>
+#include <zotnet/mts/mts.h>
 #include <grp.h>
 #include <pwd.h>
 
@@ -60,7 +60,7 @@ main (int argc, char **argv)
     m_foil (NULL);
     mts_init (invo_name);
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -358,8 +358,10 @@ setup (void)
     }
 }
 
-#ifdef	UCI
-/* UCI specific stuff for conflict */
+#ifdef UCI
+/*
+ * UCI specific stuff for conflict
+ */
 
 /* taken from <grpldr.h> */
 
@@ -376,8 +378,6 @@ struct grpldr *getglent (), *getglnam ();
 
 /* taken from the getglent() routines */
 
-#include <ctype.h>
-
 #define	MAXGLS	100
 
 static FILE *glp = NULL;
