@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static int  hdrfd = NOTOK;
 static int  txtfd = NOTOK;
