@@ -5,12 +5,12 @@
  * $Id$
  */
 
-#include "../h/nmh.h"
+#include <h/nmh.h>
 
 #ifndef	MMDFONLY
-# include "../h/mh.h"
-# include "../h/dropsbr.h"
-# include "../zotnet/mts/mts.h"
+# include <h/mh.h>
+# include <h/dropsbr.h>
+# include <zotnet/mts/mts.h>
 #else
 # include "dropsbr.h"
 # include "strings.h"
