@@ -5,81 +5,72 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 
 static struct swit switches[] = {
-#define	ALLSW	0
-    "all", 0,
-
-#define	CREATSW	1
-    "create", 0,
-#define	NCREATSW 2
-    "nocreate", 0,
-
-#define	FASTSW	3
-    "fast", 0,
-#define	NFASTSW	4
-    "nofast", 0,
-
-#define	HDRSW	5
-    "header", 0,
-#define	NHDRSW	6
-    "noheader", 0,
-
-#define	PACKSW	7
-    "pack", 0,
-#define	NPACKSW	8
-    "nopack", 0,
-#define	VERBSW	9
-    "verbose", 0,
-#define	NVERBSW	10
-    "noverbose", 0,
-
-#define	RECURSW	11
-    "recurse", 0,
-#define	NRECRSW	12
-    "norecurse", 0,
-
-#define	TOTALSW	13
-    "total", 0,
-#define	NTOTLSW	14
-    "nototal", 0,
-
-#define	PRNTSW	15
-    "print", 0,
-#define	NPRNTSW	16
-    "noprint", -4,
-#define	LISTSW	17
-    "list", 0,
-#define	NLISTSW	18
-    "nolist", 0,
-#define	PUSHSW	19
-    "push", 0,
-#define	POPSW	20
-    "pop", 0,
-
-#define VERSIONSW 21
-    "version", 0,
-#define	HELPSW	22
-    "help", 4,
-
-    NULL, 0
+#define	ALLSW           0
+    { "all", 0 },
+#define	CREATSW         1
+    { "create", 0 },
+#define	NCREATSW        2
+    { "nocreate", 0 },
+#define	FASTSW          3
+    { "fast", 0 },
+#define	NFASTSW         4
+    { "nofast", 0 },
+#define	HDRSW           5
+    { "header", 0 },
+#define	NHDRSW          6
+    { "noheader", 0 },
+#define	PACKSW          7
+    { "pack", 0 },
+#define	NPACKSW         8
+    { "nopack", 0 },
+#define	VERBSW          9
+    { "verbose", 0 },
+#define	NVERBSW        10
+    { "noverbose", 0 },
+#define	RECURSW        11
+    { "recurse", 0 },
+#define	NRECRSW        12
+    { "norecurse", 0 },
+#define	TOTALSW        13
+    { "total", 0 },
+#define	NTOTLSW        14
+    { "nototal", 0 },
+#define	PRNTSW         15
+    { "print", 0 },
+#define	NPRNTSW        16
+    { "noprint", -4 },
+#define	LISTSW         17
+    { "list", 0 },
+#define	NLISTSW        18
+    { "nolist", 0 },
+#define	PUSHSW         19
+    { "push", 0 },
+#define	POPSW          20
+    { "pop", 0 },
+#define VERSIONSW      21
+    { "version", 0 },
+#define	HELPSW         22
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 extern int errno;
 
-static int  fshort = 0;
-static int  fcreat = 0;
-static int  fpack = 0;
-static int  fverb = 0;
-static int  fheader = 0;
-static int  frecurse = 0;
-static int  ftotonly = 0;
-static int  msgtot = 0;
-static int  foldtot = 0;
-static int  start = 0;
-static int  foldp = 0;
+static int fshort = 0;
+static int fcreat = 0;
+static int fpack = 0;
+static int fverb = 0;
+static int fheader = 0;
+static int frecurse = 0;
+static int ftotonly = 0;
+static int msgtot = 0;
+static int foldtot = 0;
+static int start = 0;
+static int foldp = 0;
 
 static char *mhdir;
 static char *stack = "Folder-Stack";
@@ -114,7 +105,7 @@ main (int argc, char **argv)
     invo_name = r1bindex (argv[0], '/');
     if (argv[0][strlen (argv[0]) - 1] == 's')
 	all++;
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = m_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -123,7 +114,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -272,7 +263,8 @@ main (int argc, char **argv)
 	    m_delete (stack);
     }
     if (pushsw || popsw) {
-	if (access (cp = m_maildir (argfolder), 0) == NOTOK)
+	cp = m_maildir(argfolder);
+	if (access (cp, F_OK) == NOTOK)
 	    adios (cp, "unable to find folder");
 	m_replace (pfolder, argfolder);
 	m_update ();
@@ -526,7 +518,7 @@ addir (char *name)
     if (stat (name, &st) != NOTOK && st.st_nlink == 2)
         return;
  
-    if ((dd = opendir (name)) == NULL) {
+    if (!(dd = opendir (name))) {
 	admonish (name, "unable to read directory ");
 	return;
     }
@@ -535,7 +527,7 @@ addir (char *name)
 	    if (cp + NLENGTH(dp) + 2 >= name + BUFSIZ)
 		continue;
 	    strcpy (cp, dp->d_name);
-	    if (stat (name, &st) != NOTOK && (st.st_mode & S_IFMT) == S_IFDIR)
+	    if (stat (name, &st) != NOTOK && S_ISDIR(st.st_mode))
 		addfold (base);
 	}
     closedir (dd);
