@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/mhn.h"
+#include <h/mh.h>
+#include <h/mhn.h>
 
 #ifdef HAVE_ARPA_FTP_H
 # include <arpa/ftp.h>
@@ -51,12 +51,13 @@ extern int errno;
 /*
  * prototypes
  */
-
 struct hostent *gethostbystring ();
-
 int ftp_get (char *, char *, char *, char *, char *, char *, int, int);
 int ftp_trans (char *, char *, char *, char *, char *, char *, char *, int, int);
 
+/*
+ * static prototypes
+ */
 static int start_tcp_server (struct sockaddr_in *, int, int, int);
 static void _asprintf (char *, char *, va_list);
 static int ftp_quit (void);
