@@ -17,10 +17,10 @@
  */
 #endif
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #ifdef POP
-# include "../h/dropsbr.h"
+# include <h/dropsbr.h>
 #endif
 
 #ifdef KPOP
@@ -31,10 +31,10 @@
 # include <hesiod.h>
 #endif
 
-#include "../h/formatsbr.h"
-#include "../h/scansbr.h"
-#include "../zotnet/tws/tws.h"
-#include "../zotnet/mts/mts.h"
+#include <h/formatsbr.h>
+#include <h/scansbr.h>
+#include <zotnet/tws/tws.h>
+#include <zotnet/mts/mts.h>
 #include <errno.h>
 #include <signal.h>
 
@@ -240,7 +240,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -453,7 +453,7 @@ main (int argc, char **argv)
 go_to_it: ;
     if (host == NULL)
 #endif	/* POP */
-    if (access (newmail, 02) == NOTOK) {
+    if (access (newmail, W_OK) == NOTOK) {
 	trnflag = 0;
 	if ((in = fopen (newmail, "r")) == NULL)
 	    adios (newmail, "unable to read");
