@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static struct swit switches[] = {
 #define	ADDSW               0
@@ -57,7 +57,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -156,24 +156,23 @@ main (int argc, char **argv)
 		folder);
 
     if (debugsw) {
-	printf ("invo_name=%s mypath=%s defpath=%s\n",
-		invo_name, mypath, defpath);
-	printf ("ctxpath=%s context flags=%s\n",
-		ctxpath, sprintb (buf, (unsigned) ctxflags, DBITS));
-	printf ("foldpath=%s flags=%s\n",
-		mp->foldpath,
-		sprintb (buf, (unsigned) mp->msgflags, FBITS));
+	printf ("invo_name     = %s\n", invo_name);
+	printf ("mypath        = %s\n", mypath);
+	printf ("defpath       = %s\n", defpath);
+	printf ("ctxpath       = %s\n", ctxpath);
+	printf ("context flags = %s\n", sprintb (buf, (unsigned) ctxflags, DBITS));
+	printf ("foldpath      = %s\n", mp->foldpath);
+	printf ("folder flags  = %s\n\n", sprintb(buf, (unsigned) mp->msgflags, FBITS));
 	printf ("lowmsg=%d hghmsg=%d nummsg=%d curmsg=%d\n",
 		mp->lowmsg, mp->hghmsg, mp->nummsg, mp->curmsg);
 	printf ("lowsel=%d hghsel=%d numsel=%d\n",
 		mp->lowsel, mp->hghsel, mp->numsel);
 #ifndef	MTR
-	printf ("lowoff=%d hghoff=%d\n",
-		mp->lowoff, mp->hghoff);
-#else	/* MTR */
+	printf ("lowoff=%d hghoff=%d\n", mp->lowoff, mp->hghoff);
+#else
 	printf ("lowoff=%d hghoff=%d msgbase=0x%x msgstats=0x%x\n",
 		mp->lowoff, mp->hghoff, mp->msgbase, mp->msgstats);
-#endif	/* MTR */
+#endif
     }
 
     if (seqp == 0 && (addsw || deletesw))
@@ -207,15 +206,17 @@ main (int argc, char **argv)
     if (listsw) {
 	int bits = FFATTRSLOT;
 
-	if (seqp == 0)
+	if (seqp == 0) {
+	    char *temp;
+
 	    for (i = 0; mp->msgattrs[i]; i++)
 		printf ("%s%s: %s\n", mp->msgattrs[i],
-			mp->attrstats & (1 << (bits + i))
-			    ? " (private)" : "",
-			m_seq (mp, mp->msgattrs[i]));
-	else
+			mp->attrstats & (1 << (bits + i)) ? " (private)" : "",
+			(temp = m_seq (mp, mp->msgattrs[i])) ? temp : "empty");
+	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
 		printf ("%s: %s\n", seqs[seqp], m_seq (mp, seqs[seqp]));
+	}
 
 	if (debugsw)
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
