@@ -5,18 +5,17 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/signals.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
+#include <zotnet/tws/tws.h>
 
 #if defined(SYS5) && defined(AUX)
 # define u_short ushort
 # define u_long  ulong
 #endif
 
-#include <ctype.h>
 #include <setjmp.h>
 #include <signal.h>
 
@@ -43,9 +42,9 @@
 # define u_short ushort
 #endif
 
-#define ONECOMP		0
-#define TWOCOMP		1
-#define	BODYCOMP	2
+#define ONECOMP  0
+#define TWOCOMP  1
+#define	BODYCOMP 2
 
 #define	QUOTE	'\\'
 
@@ -149,56 +148,58 @@ static struct mcomp holder = {
     NULL, NULL, NULL, NULL, NULL, 0, 0, 0, 0, 0, NOCOMPONENT, 0
 };
 
-static struct pair {
+struct pair {
     char *p_name;
     long p_flags;
-}                   pairs[] = {
-			"Date", DATEFMT,
-                        "From", ADDRFMT | FACEDFLT,
-                        "Sender", ADDRFMT,
-                        "Reply-To", ADDRFMT,
-                        "To", ADDRFMT,
-                        "cc", ADDRFMT,
-                        "Bcc", ADDRFMT,
-			"Resent-Date", DATEFMT,
-                        "Resent-From", ADDRFMT,
-                        "Resent-Sender", ADDRFMT,
-                        "Resent-Reply-To", ADDRFMT,
-                        "Resent-To", ADDRFMT,
-                        "Resent-cc", ADDRFMT,
-                        "Resent-Bcc", ADDRFMT,
-			"Face", FACEFMT,
-
-                        NULL
 };
 
-static struct triple {
+static struct pair pairs[] = {
+    { "Date",            DATEFMT },
+    { "From",            ADDRFMT|FACEDFLT },
+    { "Sender",          ADDRFMT },
+    { "Reply-To",        ADDRFMT },
+    { "To",              ADDRFMT },
+    { "cc",              ADDRFMT },
+    { "Bcc",             ADDRFMT },
+    { "Resent-Date",     DATEFMT },
+    { "Resent-From",     ADDRFMT },
+    { "Resent-Sender",   ADDRFMT },
+    { "Resent-Reply-To", ADDRFMT },
+    { "Resent-To",       ADDRFMT },
+    { "Resent-cc",       ADDRFMT },
+    { "Resent-Bcc",      ADDRFMT },
+    { "Face",            FACEFMT },
+    NULL
+};
+
+struct triple {
     char *t_name;
     long t_on;
     long t_off;
-}                       triples[] = {
-			    "nocomponent", NOCOMPONENT, 0,
-                            "uppercase", UPPERCASE, 0,
-                            "nouppercase", 0, UPPERCASE,
-                            "center", CENTER, 0,
-                            "nocenter", 0, CENTER,
-                            "clearscreen", CLEARSCR, 0,
-                            "noclearscreen", 0, CLEARSCR,
-                            "noclear", 0, CLEARSCR,
-                            "leftadjust", LEFTADJUST, 0,
-                            "noleftadjust", 0, LEFTADJUST,
-                            "compress", COMPRESS, 0,
-                            "nocompress", 0, COMPRESS,
-                            "split", SPLIT, 0,
-                            "nosplit", 0, SPLIT,
-                            "addrfield", ADDRFMT, DATEFMT,
-                            "bell", BELL, 0,
-                            "nobell", 0, BELL,
-                            "datefield", DATEFMT, ADDRFMT,
-			    "newline", 0, NONEWLINE,
-			    "nonewline", NONEWLINE, 0,
+};
 
-                            NULL
+static struct triple triples[] = {
+    { "nocomponent",   NOCOMPONENT, 0 },
+    { "uppercase",     UPPERCASE,   0 },
+    { "nouppercase",   0,           UPPERCASE },
+    { "center",        CENTER,      0 },
+    { "nocenter",      0,           CENTER },
+    { "clearscreen",   CLEARSCR,    0 },
+    { "noclearscreen", 0,           CLEARSCR },
+    { "noclear",       0,           CLEARSCR },
+    { "leftadjust",    LEFTADJUST,  0 },
+    { "noleftadjust",  0,           LEFTADJUST },
+    { "compress",      COMPRESS,    0 },
+    { "nocompress",    0,           COMPRESS },
+    { "split",         SPLIT,       0 },
+    { "nosplit",       0,           SPLIT },
+    { "addrfield",     ADDRFMT,     DATEFMT },
+    { "bell",          BELL,        0 },
+    { "nobell",        0,           BELL },
+    { "datefield",     DATEFMT,     ADDRFMT },
+    { "newline",       0,           NONEWLINE },
+    { "nonewline",     NONEWLINE,   0 },
+    NULL
 };
 
 
@@ -288,7 +289,11 @@ int mhl (int, char **);
 int mhlsbr (int, char **, FP (*)());
 void m_pclose (void);
 
-void clear_screen();
+void clear_screen (void);             /* from termsbr.c */
+int SOprintf (char *, ...);           /* from termsbr.c */
+int sc_width (void);                  /* from termsbr.c */
+int sc_length (void);                 /* from termsbr.c */
+int sc_hardcopy (void);               /* from termsbr.c */
 struct hostent *gethostbystring ();
 
 
@@ -317,7 +322,7 @@ mhl (int argc, char **argv)
 	faceproc = cp;
 
     vecp = 0;
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, mhlswitches)) {
 		case AMBIGSW: 
@@ -501,7 +506,7 @@ mhl_format (char *file, int length, int width)
     static time_t mtime = 0;
 
     if (fmthd != NULL)
-	if (stat (libpath (file), &st) != NOTOK
+	if (stat (etcpath (file), &st) != NOTOK
 		&& mtime == st.st_mtime
 		&& dev == st.st_dev
 		&& ino == st.st_ino)
@@ -509,7 +514,7 @@ mhl_format (char *file, int length, int width)
 	else
 	    free_queue (&fmthd, &fmttl);
 
-    if ((fp = fopen (libpath (file), "r")) == NULL)
+    if ((fp = fopen (etcpath (file), "r")) == NULL)
 	adios (file, "unable to open format file");
 
     if (fstat (fileno (fp), &st) != NOTOK)
@@ -1451,7 +1456,7 @@ face_format (struct mcomp *c1)
 }
 
 
-#if defined(BSD42) || defined(SOCKETS)
+#ifdef SOCKETS
 
 /*
  * faceproc is two elements defining the image agent's location:
@@ -1518,7 +1523,7 @@ bad_faceproc: ;
     return (result != NOTOK ? OK : NOTOK);
 }
 
-#else	/* not BSD42 and not SOCKETS */
+#else /* not SOCKETS */
 
 static int
 doface (struct mcomp *c1)
@@ -1621,7 +1626,7 @@ doface (struct mcomp *c1)
 
     return result;
 }
-#endif	/* not BSD42 and not SOCKETS */
+#endif	/* not SOCKETS */
 
 
 int
@@ -1665,8 +1670,8 @@ mhlsbr (int argc, char **argv, FP (*action)())
     }
 }
 
-#undef	adios
-#undef	done
+#undef adios
+#undef done
 
 static void
 mhladios (char *what, char *fmt, ...)
