@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <signal.h>
 
 static struct swit switches[] = {
@@ -57,7 +57,7 @@ main (int argc, char **argv)
 	adios (incproc, "unable to exec");
     }
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
