@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../zotnet/mts/mts.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <zotnet/mts/mts.h>
+#include <zotnet/tws/tws.h>
 #include <pwd.h>
 
 #ifdef HESIOD
@@ -33,37 +33,31 @@
 #endif
 
 static struct swit  switches[] = {
-#define	DATESW	0
-    "date", 0,
-#define	NDATESW	1
-    "nodate", 0,
-
-#define	NOTESW	2
-    "notify type", 0,
-#define	NNOTESW	3
-    "nonotify type", 0,
-
-#define	HOSTSW	4
-    "host host", POPminc (-4),
-#define	USERSW	5
-    "user user", POPminc (-4),
-
-#define	APOPSW	6
-    "apop", APOPminc (-4),
-#define	NAPOPSW	7
-    "noapop", APOPminc (-6),
-
-#define	RPOPSW	8
-    "rpop", RPOPminc (-4),
-#define	NRPOPSW	9
-    "norpop", RPOPminc (-6),
-
-#define VERSIONSW 10
-    "version", 0,
-#define	HELPSW	11
-    "help", 4,
-
-    NULL, 0
+#define	DATESW                   0
+    { "date", 0 },
+#define	NDATESW                  1
+    { "nodate", 0 },
+#define	NOTESW                   2
+    { "notify type", 0 },
+#define	NNOTESW                  3
+    { "nonotify type", 0 },
+#define	HOSTSW                   4
+    { "host host", POPminc (-4) },
+#define	USERSW                   5
+    { "user user", POPminc (-4) },
+#define	APOPSW                   6
+    { "apop", APOPminc (-4) },
+#define	NAPOPSW                  7
+    { "noapop", APOPminc (-6) },
+#define	RPOPSW                   8
+    { "rpop", RPOPminc (-4) },
+#define	NRPOPSW                  9
+    { "norpop", RPOPminc (-6) },
+#define VERSIONSW               10
+    { "version", 0 },
+#define	HELPSW                  11
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 #define	NT_NONE	0x0
@@ -127,7 +121,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -248,14 +242,13 @@ main (int argc, char **argv)
 
 
 static struct swit ntswitches[] = {
-#define	NALLSW	0
-    "all", 0,
-#define	NMAISW	1
-    "mail", 0,
-#define	NNMAISW	2
-    "nomail", 0,
-
-    NULL, 0
+#define	NALLSW     0
+    { "all", 0 },
+#define	NMAISW     1
+    { "mail", 0 },
+#define	NNMAISW	   2
+    { "nomail", 0 },
+    { NULL, 0 }
 };
 
 
