@@ -1,6 +1,6 @@
 
 /*
- * msh.c -- The MH shell
+ * msh.c -- The nmh shell
  *
  * $Id$
  */
@@ -10,17 +10,13 @@
  *    Keep more status information in maildrop map
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
-#include "../h/dropsbr.h"
-#include "../h/formatsbr.h"
-#include "../h/scansbr.h"
-#include "../zotnet/tws/tws.h"
-#include "../zotnet/mts/mts.h"
-
-#ifdef HAVE_LIMITS_H
-# include <limits.h>
-#endif
+#include <h/mh.h>
+#include <h/signals.h>
+#include <h/dropsbr.h>
+#include <h/formatsbr.h>
+#include <h/scansbr.h>
+#include <zotnet/tws/tws.h>
+#include <zotnet/mts/mts.h>
 
 #ifdef SYS5
 # include <termio.h>
@@ -32,20 +28,8 @@
 #include <pwd.h>
 #include <setjmp.h>
 #include <signal.h>
-#include "../h/mshsbr.h"
-#include "../h/vmhsbr.h"
-
-/*
- * get maximum number of open file descriptors
- */
-#ifndef OPEN_MAX
-# ifdef NOFILE
-#  define OPEN_MAX NOFILE
-# else
-   /* so we will just pick something */
-#  define OPEN_MAX 20
-# endif
-#endif
+#include <h/mshsbr.h>
+#include <h/vmhsbr.h>
 
 #ifdef MIME
 # define MIMEminc(a) (a)
@@ -88,41 +72,44 @@ static struct swit switches[] = {
     { "help", 4 },
     { NULL, 0 }
 };
-				/* FOLDER */
-char  *fmsh = NULL;		/* folder instead of file */
-int    modified;		/* command modified folder */
-struct msgs *mp;		/* used a lot */
-static int   nMsgs = 0;
-struct Msg  *Msgs = NULL;	/* Msgs[0] not used */
-static FILE *fp;		/* input file */
-static FILE *yp = NULL;		/* temporary file */
-static int  mode;		/* mode of file */
-static int  numfds = 0;		/* number of files cached */
-static int  maxfds = 0;		/* number of files cached to be cached */
-static time_t mtime = (time_t) 0;/* mtime of file */
+
+/*
+ * FOLDER
+ */
+char*fmsh = NULL;			/* folder instead of file              */
+int modified;				/* command modified folder             */
+struct msgs *mp;			/* used a lot                          */
+static int nMsgs = 0;
+struct Msg *Msgs = NULL;		/* Msgs[0] not used                    */
+static FILE *fp;			/* input file                          */
+static FILE *yp = NULL;			/* temporary file                      */
+static int mode;			/* mode of file                        */
+static int numfds = 0;			/* number of files cached              */
+static int maxfds = 0;			/* number of files cached to be cached */
+static time_t mtime = (time_t) 0;	/* mtime of file                       */
 
 				/* VMH */
 #define	ALARM	((unsigned int) 10)
 #define	ttyN(c)	ttyNaux ((c), NULL)
 
-static int  vmh = 0;
+static int vmh = 0;
 
-static int  vmhpid = OK;
-static int  vmhfd0;
-static int  vmhfd1;
-static int  vmhfd2;
+static int vmhpid = OK;
+static int vmhfd0;
+static int vmhfd1;
+static int vmhfd2;
 
-static int  vmhtty = NOTOK;
+static int vmhtty = NOTOK;
 
 #define	SCAN	1
 #define	STATUS	2
 #define	DISPLAY	3
 #define	NWIN	DISPLAY
 
-static int  topcur = 0;
+static int topcur = 0;
 
-static int  numwins = 0;
-static int  windows[NWIN + 1];
+static int numwins = 0;
+static int windows[NWIN + 1];
 
 static jmp_buf peerenv;
 
@@ -131,46 +118,69 @@ int pmsh = 0;			/* BPOP enabled */
 extern char response[];
 #endif	/* BPOP */
 
-				/* PARENT */
-static int  pfd = NOTOK;	/* fd parent is reading from */
-static int  ppid = 0;		/* pid of parent */
+/*
+ * PARENT
+ */
+static int pfd = NOTOK;		/* fd parent is reading from */
+static int ppid = 0;		/* pid of parent             */
 
-				/* COMMAND */
+/*
+ * COMMAND
+ */
 int interactive;		/* running from a /dev/tty */
-int redirected;			/* re-directing output */
-FILE  *sp = NULL;		/* original stdout */
-
-char *cmd_name;			/* command being run */
+int redirected;			/* re-directing output     */
+FILE *sp = NULL;		/* original stdout         */
 
+char *cmd_name;			/* command being run   */
 char myfilter[BUFSIZ];		/* path to mhl.forward */
 
 static char *myprompt = "(%s) ";/* prompting string */
 
-				/* BBOARDS */
+/*
+ * BBOARDS
+ */
 static int gap;			/* gap in BBoard-ID:s */
-
-static char *myname = NULL;	/* BBoard name */
-
+static char *myname = NULL;	/* BBoard name        */
 char *BBoard_ID = "BBoard-ID";	/* BBoard-ID constant */
 
-				/* SIGNALS */
-SIGNAL_HANDLER istat;		/* original SIGINT */
-static SIGNAL_HANDLER pstat;	/* current SIGPIPE */
+/*
+ * SIGNALS
+ */
+SIGNAL_HANDLER istat;		/* original SIGINT  */
+static SIGNAL_HANDLER pstat;	/* current SIGPIPE  */
 SIGNAL_HANDLER qstat;		/* original SIGQUIT */
 
 #ifdef SIGTSTP
 SIGNAL_HANDLER tstat;		/* original SIGTSTP */
 #endif
 
-int interrupted;		/* SIGINT detected */
+int interrupted;		/* SIGINT detected  */
 int broken_pipe;		/* SIGPIPE detected */
 int told_to_quit;		/* SIGQUIT detected */
 
 #ifdef BSD42
 int should_intr;		/* signal handler should interrupt call */
-jmp_buf sigenv;			/* the environment pointer */
+jmp_buf sigenv;			/* the environment pointer              */
 #endif
 
+/*
+ * prototypes
+ */
+int SOprintf (char *, ...);  /* from termsbr.c */
+int sc_width (void);         /* from termsbr.c */
+void fsetup (char *);
+void setup (char *);
+FILE *msh_ready (int, int);
+int readids (int);
+int readid (int);
+void display_info (int);
+int expand (char *);
+void m_reset (void);
+void m_setcur (struct msgs *, int);
+void padios (char *, char *, ...);
+void padvise (char *, char *, ...);
+
+
 /*
  * static prototypes
  */
@@ -219,19 +229,6 @@ static int winR (struct Cmd *);
 static int winX (int);
 
 
-void fsetup (char *);
-void setup (char *);
-FILE *msh_ready (int, int);
-int readids (int);
-int readid (int);
-void display_info (int);
-int expand (char *);
-void m_reset (void);
-void m_setcur (struct msgs *, int);
-void padios (char *, char *, ...);
-void padvise (char *, char *, ...);
-
-
 main (int argc, char **argv)
 {
     int	id = 0, scansw = 0, vmh1 = 0, vmh2 = 0;
@@ -256,7 +253,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -362,7 +359,7 @@ main (int argc, char **argv)
 	file = "./msgbox";
     if (file && folder)
 	adios (NULL, "use a file or a folder, not both");
-    strcpy (myfilter, libpath (mhlforward));
+    strcpy (myfilter, etcpath (mhlforward));
 #ifdef	FIOCLEX
     if (pfd > 1)
 	ioctl (pfd, FIOCLEX, NULL);
@@ -417,63 +414,62 @@ main (int argc, char **argv)
 
 static struct swit mshcmds[] = {
 #define	ADVCMD	0
-    "advance", -7,
+    { "advance", -7 },
 #define	ALICMD	1
-    "ali", 0,
+    { "ali", 0 },
 #define	EXPLCMD	2
-    "burst", 0,
+    { "burst", 0 },
 #define	COMPCMD	3
-    "comp", 0,
+    { "comp", 0 },
 #define	DISTCMD	4
-    "dist", 0,
+    { "dist", 0 },
 #define	EXITCMD	5
-    "exit", 0,
+    { "exit", 0 },
 #define	FOLDCMD	6
-    "folder", 0,
+    { "folder", 0 },
 #define	FORWCMD	7
-    "forw", 0,
+    { "forw", 0 },
 #define	HELPCMD	8
-    "help", 0,
+    { "help", 0 },
 #define	INCMD	9
-    "inc", 0,
+    { "inc", 0 },
 #define	MARKCMD	10
-    "mark", 0,
+    { "mark", 0 },
 #define	MAILCMD	11
-    "mhmail", 0,
+    { "mhmail", 0 },
 #define	MHNCMD	12
-    "mhn", MIMEminc(-3),
+    { "mhn", MIMEminc(-3) },
 #define	MSGKCMD	13
-    "msgchk", 0,
+    { "msgchk", 0 },
 #define	NEXTCMD	14
-    "next", 0,
+    { "next", 0 },
 #define	PACKCMD	15
-    "packf", 0,
+    { "packf", 0 },
 #define	PICKCMD	16
-    "pick", 0,
+    { "pick", 0 },
 #define	PREVCMD	17
-    "prev", 0,
+    { "prev", 0 },
 #define	QUITCMD	18
-    "quit", 0,
+    { "quit", 0 },
 #define	FILECMD	19
-    "refile", 0,
+    { "refile", 0 },
 #define	REPLCMD	20
-    "repl", 0,
+    { "repl", 0 },
 #define	RMMCMD	21
-    "rmm", 0,
+    { "rmm", 0 },
 #define	SCANCMD	22
-    "scan", 0,
+    { "scan", 0 },
 #define	SENDCMD	23
-    "send", 0,
+    { "send", 0 },
 #define	SHOWCMD	24
-    "show", 0,
+    { "show", 0 },
 #define	SORTCMD	25
-    "sortm", 0,
+    { "sortm", 0 },
 #define	WHATCMD	26
-    "whatnow", 0,
+    { "whatnow", 0 },
 #define	WHOMCMD	27
-    "whom", 0,
-
-    NULL, 0
+    { "whom", 0 },
+    { NULL, 0 }
 };
 
 
@@ -770,7 +766,7 @@ setup (char *file)
     else {
 #endif	/* BPOP */
 	stat (file, &st);
-	if (st.st_uid != getuid () || access (file, 02) == NOTOK)
+	if (st.st_uid != getuid () || access (file, W_OK) == NOTOK)
 	    mp->msgflags |= READONLY;
 #ifdef	BPOP
     }
