@@ -5,17 +5,17 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
-#include "../h/dropsbr.h"
-#include "../h/formatsbr.h"
-#include "../h/scansbr.h"
-#include "../zotnet/tws/tws.h"
-#include "../zotnet/mts/mts.h"
+#include <h/mh.h>
+#include <h/signals.h>
+#include <h/dropsbr.h>
+#include <h/formatsbr.h>
+#include <h/scansbr.h>
+#include <zotnet/tws/tws.h>
+#include <zotnet/mts/mts.h>
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
-#include "../h/mshsbr.h"
+#include <h/mshsbr.h>
 
 extern int errno;
 
@@ -44,7 +44,9 @@ typedef int (*qsort_comp) (const void *, const void *);
 /*
  * prototypes
  */
-void clear_screen ();
+void clear_screen (void);   /* from termsbr.c */
+int SOprintf (char *, ...); /* from termsbr.c */
+int sc_width (void);        /* from termsbr.c */
 
 /*
  * static prototypes
@@ -587,7 +589,7 @@ filehak (char **args)
 	    cwd = getcpy (pwd ());
 	chdir (m_maildir (""));
 	cp = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	if (access (m_maildir (cp), 0) == NOTOK)
+	if (access (m_maildir (cp), F_OK) == NOTOK)
 	    result = OK;
 	free (cp);
     }
@@ -713,7 +715,7 @@ foldcmd (char **args)
 	    return;
 	}
 	if (fmsh) {
-	    if (access (m_maildir (folder), 04) == NOTOK) {
+	    if (access (m_maildir (folder), R_OK) == NOTOK) {
 		advise (folder, "unable to read");
 		return;
 	    }
@@ -723,7 +725,7 @@ foldcmd (char **args)
 	    if (expand (buf) == NOTOK)
 		return;
 	    folder = buf;
-	    if (access (folder, 04) == NOTOK) {
+	    if (access (folder, R_OK) == NOTOK) {
 		advise (folder, "unable to read");
 		return;
 	    }
@@ -915,7 +917,7 @@ forwcmd (char **args)
 		    }
 		    continue;
 		case FOFTSW: 
-		    if (access (filter = myfilter, 04) == NOTOK) {
+		    if (access (filter = myfilter, R_OK) == NOTOK) {
 			advise (filter, "unable to read default filter file");
 			return;
 		    }
@@ -948,7 +950,7 @@ forwcmd (char **args)
 	strcpy (buf, filter);
 	if (expand (buf) == NOTOK)
 	    return;
-	if (access (filter = getcpy (libpath (buf)), 04) == NOTOK) {
+	if (access (filter = getcpy (etcpath (buf)), R_OK) == NOTOK) {
 	    advise (filter, "unable to read");
 	    free (filter);
 	    return;
@@ -1093,28 +1095,27 @@ helpcmd (char **args)
 
 
 static struct swit markswit[] = {
-#define	MADDSW	0
-    "add", 0,
-#define	MDELSW	1
-    "delete", 0,
-#define	MLSTSW	2
-    "list", 0,
-#define	MSEQSW	3
-    "sequence name", 0,
-#define	MPUBSW	4
-    "public", 0,
-#define	MNPUBSW	5
-    "nopublic", 0,
-#define	MZERSW	6
-    "zero", 0,
-#define	MNZERSW	7
-    "nozero", 0,
-#define	MHELP	8
-    "help", 4,
-#define	MDBUGSW	9
-    "debug", -5,
-
-    NULL, 0
+#define	MADDSW             0
+    { "add", 0 },
+#define	MDELSW             1
+    { "delete", 0 },
+#define	MLSTSW             2
+    { "list", 0 },
+#define	MSEQSW             3
+    { "sequence name", 0 },
+#define	MPUBSW             4
+    { "public", 0 },
+#define	MNPUBSW            5
+    { "nopublic", 0 },
+#define	MZERSW             6
+    { "zero", 0 },
+#define	MNZERSW            7
+    { "nozero", 0 },
+#define	MHELP              8
+    { "help", 4 },
+#define	MDBUGSW            9
+    { "debug", -5 },
+    { NULL, 0 }
 };
 
 
@@ -1295,66 +1296,65 @@ markcmd (char **args)
 
 #ifdef MIME
 static struct swit mhnswit[] = {
-#define	MHNAUTOSW	  0
-    "auto", 0,
-#define	MHNNAUTOSW	  1
-    "noauto", 0,
-#define	MHNDEBUGSW	  2
-    "debug", -5,
-#define	MHNEBCDICSW 	 3
-    "ebcdicsafe", 0,
-#define	MHNNEBCDICSW	 4
-    "noebcdicsafe", 0,
-#define	MHNFORMSW	  5
-    "form formfile", 4,
-#define	MHNHEADSW	  6
-    "headers", 0,
-#define	MHNNHEADSW	  7
-    "noheaders", 0,
-#define	MHNLISTSW	  8
-    "list", 0,
-#define	MHNNLISTSW	  9
-    "nolist", 0,
-#define	MHNPARTSW	 10
-    "part number", 0,
-#define	MHNSIZESW	 11
-    "realsize", 0,
-#define	MHNNSIZESW	 12
-    "norealsize", 0,
-#define	MHNRFC934SW	 13
-    "rfc934mode", 0,
-#define	MHNNRFC934SW	 14
-    "norfc934mode", 0,
-#define	MHNSERIALSW	 15
-    "serialonly", 0,
-#define	MHNNSERIALSW	 16
-    "noserialonly", 0,
-#define	MHNSHOWSW	 17
-    "show", 0,
-#define	MHNNSHOWSW	 18
-    "noshow", 0,
-#define	MHNSTORESW	 19
-    "store", 0,
-#define	MHNNSTORESW	 20
-    "nostore", 0,
-#define	MHNTYPESW	 21
-    "type content", 0,
-#define	MHNVERBSW	 22
-    "verbose", 0,
-#define	MHNNVERBSW	 23
-    "noverbose", 0,
-#define	MHNHELPSW	 24
-    "help", 4,
-#define	MHNPROGSW	 25
-    "moreproc program", -4,
-#define	MHNNPROGSW	 26
-    "nomoreproc", -3,
-#define	MHNLENSW	 27
-    "length lines", -4,
-#define	MHNWIDSW	 28
-    "width columns", -4,
-
-    NULL, 0
+#define	MHNAUTOSW	    0
+    { "auto", 0 },
+#define	MHNNAUTOSW	    1
+    { "noauto", 0 },
+#define	MHNDEBUGSW	    2
+    { "debug", -5 },
+#define	MHNEBCDICSW 	    3
+    { "ebcdicsafe", 0 },
+#define	MHNNEBCDICSW	    4
+    { "noebcdicsafe", 0 },
+#define	MHNFORMSW	    5
+    { "form formfile", 4 },
+#define	MHNHEADSW	    6
+    { "headers", 0 },
+#define	MHNNHEADSW	    7
+    { "noheaders", 0 },
+#define	MHNLISTSW	    8
+    { "list", 0 },
+#define	MHNNLISTSW	    9
+    { "nolist", 0 },
+#define	MHNPARTSW	   10
+    { "part number", 0 },
+#define	MHNSIZESW	   11
+    { "realsize", 0 },
+#define	MHNNSIZESW	   12
+    { "norealsize", 0 },
+#define	MHNRFC934SW	   13
+    { "rfc934mode", 0 },
+#define	MHNNRFC934SW	   14
+    { "norfc934mode", 0 },
+#define	MHNSERIALSW	   15
+    { "serialonly", 0 },
+#define	MHNNSERIALSW	   16
+    { "noserialonly", 0 },
+#define	MHNSHOWSW	   17
+    { "show", 0 },
+#define	MHNNSHOWSW	   18
+    { "noshow", 0 },
+#define	MHNSTORESW	   19
+    { "store", 0 },
+#define	MHNNSTORESW	   20
+    { "nostore", 0 },
+#define	MHNTYPESW	   21
+    { "type content", 0 },
+#define	MHNVERBSW	   22
+    { "verbose", 0 },
+#define	MHNNVERBSW	   23
+    { "noverbose", 0 },
+#define	MHNHELPSW	   24
+    { "help", 4 },
+#define	MHNPROGSW	   25
+    { "moreproc program", -4 },
+#define	MHNNPROGSW	   26
+    { "nomoreproc", -3 },
+#define	MHNLENSW	   27
+    { "length lines", -4 },
+#define	MHNWIDSW	   28
+    { "width columns", -4 },
+    { NULL, 0 }
 };
 
 
@@ -1455,16 +1455,14 @@ mhncmd (char **args)
     m_setcur (mp, mp->hghsel);
 }
 
-
 #endif /* MIME */
+
 static struct swit packswit[] = {
-#define	PAFISW	0
-    "file name", 0,
-
-#define	PAHELP	1
-    "help", 4,
-
-    NULL, 0
+#define	PAFISW         0
+    { "file name", 0 },
+#define	PAHELP         1
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -1587,7 +1585,7 @@ packhak (char **args)
     }
 
     file = path (file ? file : "./msgbox", TFILE);
-    result = access (file, 0) == NOTOK ? OK : NOTOK;
+    result = access (file, F_OK) == NOTOK ? OK : NOTOK;
     free (file);
 
     return result;
@@ -1595,55 +1593,53 @@ packhak (char **args)
 
 
 static struct swit pickswit[] = {
-#define	PIANSW	0
-    "and", 0,
-#define	PIORSW	1
-    "or", 0,
-#define	PINTSW	2
-    "not", 0,
-#define	PILBSW	3
-    "lbrace", 0,
-#define	PIRBSW	4
-    "rbrace", 0,
-
-#define	PICCSW	5
-    "cc  pattern", 0,
-#define	PIDASW	6
-    "date  pattern", 0,
-#define	PIFRSW	7
-    "from  pattern", 0,
-#define	PISESW	8
-    "search  pattern", 0,
-#define	PISUSW	9
-    "subject  pattern", 0,
-#define	PITOSW	10
-    "to  pattern", 0,
-#define	PIOTSW	11
-    "-othercomponent  pattern", 15,
-#define	PIAFSW	12
-    "after date", 0,
-#define	PIBFSW	13
-    "before date", 0,
-#define	PIDFSW	14
-    "datefield field", 5,
-#define	PISQSW	15
-    "sequence name", 0,
-#define	PIPUSW	16
-    "public", 0,
-#define	PINPUSW	17
-    "nopublic", 0,
-#define	PIZRSW	18
-    "zero", 0,
-#define	PINZRSW	19
-    "nozero", 0,
-#define	PILISW	20
-    "list", 0,
-#define	PINLISW	21
-    "nolist", 0,
-#define	PIHELP	22
-    "help", 4,
-
-    NULL, 0
+#define	PIANSW                0
+    { "and", 0 },
+#define	PIORSW                1
+    { "or", 0 },
+#define	PINTSW                2
+    { "not", 0 },
+#define	PILBSW                3
+    { "lbrace", 0 },
+#define	PIRBSW                4
+    { "rbrace", 0 },
+#define	PICCSW                5
+    { "cc  pattern", 0 },
+#define	PIDASW                6
+    { "date  pattern", 0 },
+#define	PIFRSW                7
+    { "from  pattern", 0 },
+#define	PISESW                8
+    { "search  pattern", 0 },
+#define	PISUSW                9
+    { "subject  pattern", 0 },
+#define	PITOSW               10
+    { "to  pattern", 0 },
+#define	PIOTSW               11
+    { "-othercomponent  pattern", 15 },
+#define	PIAFSW               12
+    { "after date", 0 },
+#define	PIBFSW               13
+    { "before date", 0 },
+#define	PIDFSW               14
+    { "datefield field", 5 },
+#define	PISQSW               15
+    { "sequence name", 0 },
+#define	PIPUSW               16
+    { "public", 0 },
+#define	PINPUSW              17
+    { "nopublic", 0 },
+#define	PIZRSW               18
+    { "zero", 0 },
+#define	PINZRSW              19
+    { "nozero", 0 },
+#define	PILISW               20
+    { "list", 0 },
+#define	PINLISW              21
+    { "nolist", 0 },
+#define	PIHELP               22
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -1795,48 +1791,47 @@ pattern: ;
 
 
 static struct swit replswit[] = {
-#define	REANSW	0
-    "annotate", 0,
-#define	RENANSW	1
-    "noannotate", 0,
-#define	RECCSW	2
-    "cc type", 0,
-#define	RENCCSW	3
-    "nocc type", 0,
-#define	REDFSW	4
-    "draftfolder +folder", 0,
-#define	REDMSW	5
-    "draftmessage msg", 0,
-#define	RENDFSW	6
-    "nodraftfolder", 0,
-#define	REEDTSW	7
-    "editor editor", 0,
-#define	RENEDSW	8
-    "noedit", 0,
-#define	REFCCSW	9
-    "fcc +folder", 0,
-#define	REFLTSW	10
-    "filter filterfile", 0,
-#define	REFRMSW	11
-    "form formfile", 0,
-#define	REINSW	12
-    "inplace", 0,
-#define	RENINSW	13
-    "noinplace", 0,
-#define	REQUSW	14
-    "query", 0,
-#define	RENQUSW	15
-    "noquery", 0,
-#define	REWHTSW	16
-    "whatnowproc program", 0,
-#define	RENWTSW	17
-    "nowhatnow", 0,
-#define	REWIDSW	19
-    "width columns", 0,
-#define	REHELP	20
-    "help", 4,
-
-    NULL, 0
+#define	REANSW                  0
+    { "annotate", 0 },
+#define	RENANSW                 1
+    { "noannotate", 0 },
+#define	RECCSW                  2
+    { "cc type", 0 },
+#define	RENCCSW                 3
+    { "nocc type", 0 },
+#define	REDFSW                  4
+    { "draftfolder +folder", 0 },
+#define	REDMSW                  5
+    { "draftmessage msg", 0 },
+#define	RENDFSW                 6
+    { "nodraftfolder", 0 },
+#define	REEDTSW                 7
+    { "editor editor", 0 },
+#define	RENEDSW                 8
+    { "noedit", 0 },
+#define	REFCCSW                 9
+    { "fcc +folder", 0 },
+#define	REFLTSW                10
+    { "filter filterfile", 0 },
+#define	REFRMSW                11
+    { "form formfile", 0 },
+#define	REINSW                 12
+    { "inplace", 0 },
+#define	RENINSW                13
+    { "noinplace", 0 },
+#define	REQUSW                 14
+    { "query", 0 },
+#define	RENQUSW                15
+    { "noquery", 0 },
+#define	REWHTSW                16
+    { "whatnowproc program", 0 },
+#define	RENWTSW                17
+    { "nowhatnow", 0 },
+#define	REWIDSW                19
+    { "width columns", 0 },
+#define	REHELP                 20
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -1930,10 +1925,9 @@ replcmd (char **args)
 
 
 static struct swit rmmswit[] = {
-#define	RMHELP	0
-    "help", 4,
-
-    NULL, 0
+#define	RMHELP    0
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -2046,24 +2040,23 @@ rmm (void)
 
 
 static struct swit scanswit[] = {
-#define	SCCLR	0
-    "clear", 0,
-#define	SCNCLR	1
-    "noclear", 0,
-#define	SCFORM	2
-    "form formatfile", 0,
-#define	SCFMT	3
-    "format string", 5,
-#define	SCHEAD	4
-    "header", 0,
-#define SCNHEAD	5
-    "noheader", 0,
-#define	SCWID	6
-    "width columns", 0,
-#define	SCHELP	7
-    "help", 4,
-
-    NULL, 0
+#define	SCCLR              0
+    { "clear", 0 },
+#define	SCNCLR             1
+    { "noclear", 0 },
+#define	SCFORM             2
+    { "form formatfile", 0 },
+#define	SCFMT              3
+    { "format string", 5 },
+#define	SCHEAD             4
+    { "header", 0 },
+#define SCNHEAD            5
+    { "noheader", 0 },
+#define	SCWID              6
+    { "width columns", 0 },
+#define	SCHELP             7
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -2290,30 +2283,29 @@ scancmd (char **args)
 
 
 static struct swit showswit[] = {
-#define	SHDRAFT	0
-    "draft", 5,
-#define	SHFORM	1
-    "form formfile", 4,
-#define	SHPROG	2
-    "moreproc program", 4,
-#define	SHNPROG	3
-    "nomoreproc", 3,
-#define	SHLEN	4
-    "length lines", 4,
-#define	SHWID	5
-    "width columns", 4,
-#define	SHSHOW	6
-    "showproc program", 4,
-#define	SHNSHOW	7
-    "noshowproc", 3,
-#define	SHHEAD	8
-    "header", 4,
-#define SHNHEAD	9
-    "noheader", 3,
-#define	SHHELP	10
-    "help", 4,
-
-    NULL, 0
+#define	SHDRAFT               0
+    { "draft", 5 },
+#define	SHFORM                1
+    { "form formfile", 4 },
+#define	SHPROG                2
+    { "moreproc program", 4 },
+#define	SHNPROG               3
+    { "nomoreproc", 3 },
+#define	SHLEN                 4
+    { "length lines", 4 },
+#define	SHWID                 5
+    { "width columns", 4 },
+#define	SHSHOW                6
+    { "showproc program", 4 },
+#define	SHNSHOW               7
+    { "noshowproc", 3 },
+#define	SHHEAD                8
+    { "header", 4 },
+#define SHNHEAD               9
+    { "noheader", 3 },
+#define	SHHELP               10
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
@@ -2559,7 +2551,7 @@ ask (int msgnum)
 
 
 #ifdef MIME
-#include "../h/mhn.h"
+#include <h/mhn.h>
 
 
 static int
@@ -2718,24 +2710,23 @@ out: ;
 
 
 static struct swit sortswit[] = {
-#define	SODATE	0
-    "datefield field", 0,
-#define	SOSUBJ	1
-    "textfield field", 0,
-#define	SONSUBJ	2
-    "notextfield", 0,
-#define	SOLIMT	3
-    "limit days", 0,
-#define	SONLIMT	4
-    "nolimit", 0,
-#define	SOVERB	5
-    "verbose", 0,
-#define	SONVERB	6
-    "noverbose", 0,
-#define	SOHELP	7
-    "help", 4,
-
-    NULL, 0
+#define	SODATE               0
+    { "datefield field", 0 },
+#define	SOSUBJ               1
+    { "textfield field", 0 },
+#define	SONSUBJ              2
+    { "notextfield", 0 },
+#define	SOLIMT               3
+    { "limit days", 0 },
+#define	SONLIMT              4
+    { "nolimit", 0 },
+#define	SOVERB               5
+    { "verbose", 0 },
+#define	SONVERB              6
+    { "noverbose", 0 },
+#define	SOHELP               7
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 
