@@ -5,16 +5,16 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/dropsbr.h"
+#include <h/mh.h>
+#include <h/dropsbr.h>
 #include <errno.h>
 
 static struct swit switches[] = {
-#define FILESW          0
+#define FILESW         0
     { "file name", 0 },
-#define VERSIONSW       1
+#define VERSIONSW      1
     { "version", 0 },
-#define	HELPSW          2
+#define	HELPSW         2
     { "help", 4 },
     { NULL, 0 }
 };
@@ -47,7 +47,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
