@@ -5,19 +5,12 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/formatsbr.h"
-#include "../h/scansbr.h"
+#include <h/mh.h>
+#include <h/formatsbr.h>
+#include <h/scansbr.h>
+#include <zotnet/mts/mts.h>
 #include <errno.h>
 
-#ifdef SMTP
-# include "../h/local.h"
-#else	/* SMTP */
-# include <sys/stat.h>
-#endif	/* SMTP */
-
-#include "../zotnet/mts/mts.h"
-
 #ifndef	RPOP
 # define RPOPminc(a) (a)
 #else
@@ -43,64 +36,53 @@
 #endif
 
 static struct swit  switches[] = {
-#define	APOPSW	0
-    "apop", APOPminc (-4),
-#define	NAPOPSW	1
-    "noapop", APOPminc (-6),
-
-#define	AUTOSW	2
-    "auto", BPOPminc(-4),
-#define	NAUTOSW	3
-    "noauto", BPOPminc(-6),
-
-#define	BULKSW	4
-    "bulk directory", BULKminc(-4),
-
-#define	FORMSW	5
-    "form formatfile", 0,
-
-#define	FMTSW	6
-    "format string", 5,
-
-#define	HOSTSW	7
-    "host host", 0,
-
-#define	PROGSW	8
-    "mshproc program", 0,
-
-#define	RPOPSW	9
-    "rpop", RPOPminc (-4),
-#define	NRPOPSW	10
-    "norpop", RPOPminc (-6),
-
-#define	USERSW	11
-    "user user", 0,
-
-#define	WIDSW	12
-    "width columns", 0,
-
-#define VERSIONSW 13
-    "version", 0,
-#define	HELPSW	14
-    "help", 4,
-
-    NULL, 0
+#define	APOPSW                  0
+    { "apop", APOPminc (-4) },
+#define	NAPOPSW                 1
+    { "noapop", APOPminc (-6) },
+#define	AUTOSW                  2
+    { "auto", BPOPminc(-4) },
+#define	NAUTOSW                 3
+    { "noauto", BPOPminc(-6) },
+#define	BULKSW                  4
+    { "bulk directory", BULKminc(-4) },
+#define	FORMSW                  5
+    { "form formatfile", 0 },
+#define	FMTSW                   6
+    { "format string", 5 },
+#define	HOSTSW                  7
+    { "host host", 0 },
+#define	PROGSW                  8
+    { "mshproc program", 0 },
+#define	RPOPSW                  9
+    { "rpop", RPOPminc (-4) },
+#define	NRPOPSW                10
+    { "norpop", RPOPminc (-6) },
+#define	USERSW                 11
+    { "user user", 0 },
+#define	WIDSW                  12
+    { "width columns", 0 },
+#define VERSIONSW              13
+    { "version", 0 },
+#define	HELPSW                 14
+    { "help", 4 },
+    { NULL, 0 }
 };
 
+static char *bulksw = NULL;
+static int snoop = 0;
+static int width = 0;
+static char mailname[BUFSIZ];
+static char *nfs = NULL;
+static struct msgs *mp;
 
-static	char   *bulksw = NULL;
-static	int	snoop = 0;
-static	int	width = 0;
+extern int errno;
+extern char response[];
 
-static	char	mailname[BUFSIZ];
-
-static	char   *nfs = NULL;
-
-static	struct msgs *mp;
-
-extern	int	errno;
-
-extern	char	response[];
+/*
+ * prototypes
+ */
+int sc_width (void);  /* from termsbr.c */
 
 
 main (int argc, char **argv)
@@ -531,8 +513,8 @@ msh (void)
 
 
 #ifdef SMTP
-#include "../zotnet/mts/mts.h"
-#include "../mts/sendmail/smail.h"
+#include <zotnet/mts/mts.h>
+#include <mts/sendmail/smail.h>
 
 
 static int
