@@ -5,18 +5,18 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #if defined(NNTP) && !defined(PSHSBR)
 # undef NNTP
 #endif
 
 #ifdef NNTP			/* building pshsbr.o from popsbr.c */
-# include "../h/nntp.h"
+# include <h/nntp.h>
 #endif /* NNTP */
 
 #if !defined(NNTP) && defined(APOP)
-# include "../h/md5.h"
+# include <h/md5.h>
 #endif
 
 #include <signal.h>
