@@ -5,40 +5,36 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
-#include "../h/addrsbr.h"
-#include "../h/aliasbr.h"
-#include "../h/dropsbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/signals.h>
+#include <h/addrsbr.h>
+#include <h/aliasbr.h>
+#include <h/dropsbr.h>
+#include <zotnet/tws/tws.h>
 
 #ifndef	MMDFMTS
-# include <ctype.h>
 # include <errno.h>
 # include <setjmp.h>
-# include <stdio.h>
-# include <sys/types.h>
-#else	/* MMDFMTS */
-# include "../mts/mmdf/util.h"
-# include "../mts/mmdf/mmdf.h"
-#endif	/* MMDFMTS */
+#else
+# include <mts/mmdf/util.h>
+# include <mts/mmdf/mmdf.h>
+#endif
 
-#include "../zotnet/mts/mts.h"
+#include <zotnet/mts/mts.h>
 
 #ifdef MHMTS
 # include <sys/ioctl.h>
-# include <sys/stat.h>
 #endif
 
 #ifdef SENDMTS
-# include "../mts/sendmail/smail.h"
+# include <mts/sendmail/smail.h>
 # undef	MF
 #endif
 
 #include <signal.h>
 
 #ifdef MIME
-# include "../h/mhn.h"
+# include <h/mhn.h>
 #endif
 
 #ifndef	MMDFMTS
@@ -358,15 +354,10 @@ static void do_addresses (char *, int, int, int, int);
 
 main (int argc, char **argv)
 {
-    int     state,
-            compnum;
-    char   *cp,
-           *msg = NULL,
-          **argp = argv + 1,
-            buf[BUFSIZ],
-            name[NAMESZ];
-    FILE   *in,
-	   *out;
+    int state, compnum;
+    char *cp, *msg = NULL, **argp = argv + 1;
+    char buf[BUFSIZ], name[NAMESZ];
+    FILE *in, *out;
 
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
@@ -380,7 +371,7 @@ main (int argc, char **argv)
 #endif	/* MMDFII */
 #endif	/* MMDFMTS */
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -407,7 +398,7 @@ main (int argc, char **argv)
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 #ifdef	MHMTS
-		    if (access (libpath (cp), 04) == NOTOK)
+		    if (access (etcpath (cp), R_OK) == NOTOK)
 			adios (cp, "unable to read");
 #endif	/* MHMTS */
 		    if ((state = alias (cp)) != AK_OK)
@@ -598,7 +589,7 @@ main (int argc, char **argv)
 	adios (NULL, "impossible width %d", outputlinelen);
 
 #ifdef	MHMTS
-    if (access (msg, 04) == NOTOK)
+    if (access (msg, R_OK) == NOTOK)
 	adios (msg, "unable to read");
 #endif	/* MHMTS */
     if ((in = fopen (msg, "r")) == NULL)
@@ -2376,7 +2367,7 @@ localmail (struct mailname *lp, int talk, int fd)
 	    mmdfldir[0] ? mmdfldir : hp->h_home,
 	    mmdflfil[0] ? mmdflfil : hp->h_name);
 
-    switch (access (slocalproc, 01)) {
+    switch (access (slocalproc, X_OK)) {
 	default: 
 	    if (talk)
 		printf ("(invoking hook)\n\t");
