@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 
 #ifdef HAVE_TERMIOS_H
@@ -28,7 +28,7 @@
 
 #include <signal.h>
 
-#define	QUOTE	'\\'
+#define	QUOTE '\\'
 
 #ifndef	CKILL
 # define CKILL '@'
@@ -126,7 +126,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++)
+    while ((cp = *argp++))
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
