@@ -5,10 +5,10 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/formatsbr.h"
-#include "../h/rcvmail.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/formatsbr.h>
+#include <h/rcvmail.h>
+#include <zotnet/tws/tws.h>
 
 static struct swit switches[] = {
 #define	FORMSW	0
@@ -53,7 +53,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
