@@ -5,11 +5,11 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/dropsbr.h"
-#include "../h/rcvmail.h"
-#include "../zotnet/tws/tws.h"
-#include "../zotnet/mts/mts.h"
+#include <h/mh.h>
+#include <h/dropsbr.h>
+#include <h/rcvmail.h>
+#include <zotnet/tws/tws.h>
+#include <zotnet/mts/mts.h>
 
 static struct swit switches[] = {
 #define VERSIONSW 0
@@ -41,7 +41,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
