@@ -5,35 +5,30 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 #include <signal.h>
 
 static struct swit switches[] = {
-#define CRETSW	0
-    "create",	0,
-#define NCRETSW	1
-    "nocreate", 0,
-
-#define PUBSW	2
-    "public",	0,
-#define NPUBSW	3
-    "nopublic",  0,
-
-#define SEQSW	4
-    "sequence name", 0,
-
-#define ZEROSW  5
-    "zero",	0,
-#define NZEROSW 6
-    "nozero",	0,
-
-#define VERSIONSW 7
-    "version", 0,
-#define HELPSW  8
-    "help", 4,
-
-    NULL, 0
+#define CRETSW         0
+    { "create",	0 },
+#define NCRETSW        1
+    { "nocreate", 0 },
+#define PUBSW          2
+    { "public",	0 },
+#define NPUBSW         3
+    { "nopublic",  0 },
+#define SEQSW          4
+    { "sequence name", 0 },
+#define ZEROSW         5
+    { "zero",	0 },
+#define NZEROSW        6
+    { "nozero",	0 },
+#define VERSIONSW      7
+    { "version", 0 },
+#define HELPSW         8
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 extern int errno;
@@ -64,7 +59,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -145,8 +140,8 @@ main (int argc, char **argv)
     signal (SIGQUIT, SIG_IGN);
     signal (SIGTERM, SIG_IGN);
 
-    if ((fd = creat (tmpfilenam = m_scratch ("", invo_name), m_gmprot ()))
-	    == NOTOK)
+    tmpfilenam = m_scratch ("", invo_name);
+    if ((fd = creat (tmpfilenam, m_gmprot ())) == NOTOK)
 	adios (tmpfilenam, "unable to create");
     chmod (tmpfilenam, m_gmprot ());
 
@@ -166,7 +161,8 @@ main (int argc, char **argv)
 
     msgnum = mp->hghmsg;
     do {
-	msgnum++, mp->hghmsg++;
+	msgnum++;
+	mp->hghmsg++;
 	if (msgnum > mp->hghoff)
 	    if (!(mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)))
 		adios (NULL, "unable to allocate folder storage");
