@@ -9,10 +9,10 @@
 # undef TTYD
 #endif
 
-#include "../h/mh.h"
-#include "../h/rcvmail.h"
-#include "../h/scansbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/rcvmail.h>
+#include <h/scansbr.h>
+#include <zotnet/tws/tws.h>
 #include <signal.h>
 
 #ifndef	TTYD
@@ -89,7 +89,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
