@@ -5,40 +5,33 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 
 static struct swit switches[] = {
-#define	DRAFTSW	0
-    "draft", 0,
-
-#define	LINKSW	1
-    "link", 0,
-#define	NLINKSW	2
-    "nolink", 0,
-
-#define	PRESSW	3
-    "preserve", 0,
-#define	NPRESSW	4
-    "nopreserve", 0,
-
-#define	SRCSW	5
-    "src +folder", 0,
-
-#define	FILESW	6
-    "file file", 0,
-
-#define	RPROCSW	7
-    "rmmproc program", 0,
-#define	NRPRCSW 8
-    "normmproc", 0,
-
-#define VERSIONSW 9
-    "version", 0,
-#define	HELPSW	10
-    "help", 4,
-
-    NULL, 0
+#define	DRAFTSW          0
+    { "draft", 0 },
+#define	LINKSW           1
+    { "link", 0 },
+#define	NLINKSW          2
+    { "nolink", 0 },
+#define	PRESSW           3
+    { "preserve", 0 },
+#define	NPRESSW          4
+    { "nopreserve", 0 },
+#define	SRCSW            5
+    { "src +folder", 0 },
+#define	FILESW           6
+    { "file file", 0 },
+#define	RPROCSW          7
+    { "rmmproc program", 0 },
+#define	NRPRCSW          8
+    { "normmproc", 0 },
+#define VERSIONSW        9
+    { "version", 0 },
+#define	HELPSW          10
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 extern int  errno;
@@ -85,7 +78,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
