@@ -5,27 +5,28 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
 #include <sys/file.h>		/* L_SET */
 
-extern short    ccto,		/* from repl.c */
-                cccc,
-                ccme,
-                format,
-                outputlinelen,
-		querysw;
-extern char *fcc,
-	    *filter,
-            *form;
+extern short ccto;		/* from repl.c */
+extern short cccc;
+extern short ccme;
+extern short format;
+extern short outputlinelen;
+extern short querysw;
 
-static int   dftype=0;
+extern char *fcc;
+extern char *filter;
+extern char *form;
+
+static int dftype=0;
 
 static char *badaddrs = NULL;
-static char *dfhost=NULL;
+static char *dfhost = NULL;
 
-static struct mailname  mq={NULL};
+static struct mailname mq = { NULL };
 
 #define SBUFSIZ 256		
 				/* buffer size for content part of header
@@ -71,18 +72,18 @@ static void replfilter (FILE *, FILE *);
 void
 replout (FILE *inb, char *msg, char *drft)
 {
-    register int  state;
-    register int  i;
+    register int state;
+    register int i;
     register struct comp *cptr;
     register char *tmpbuf;
     register char **nxtbuf;
     register struct comp **savecomp;
-    FILE    *out;
-    char    name[NAMESZ];
-    char    *scanl;
-    int	    char_read = 0;
-    char    *cp;
-    int      format_len;
+    FILE *out;
+    char name[NAMESZ];
+    char *scanl;
+    int	char_read = 0;
+    char *cp;
+    int format_len;
     register char **ap;
 
     umask( ~ m_gmprot() );
@@ -357,7 +358,7 @@ formataddr (char *orig, char *str)
 static int
 insert (struct mailname *np)
 {
-    char    buffer[BUFSIZ];
+    char buffer[BUFSIZ];
     register struct mailname *mp;
 
     if (np->m_mbox == NULL)
@@ -399,7 +400,7 @@ replfilter (FILE *in, FILE *out)
     if (filter == NULL)
 	return;
 
-    if (access (filter, 04) == NOTOK)
+    if (access (filter, R_OK) == NOTOK)
 	adios (filter, "unable to read");
 
     mhl = r1bindex (mhlproc, '/');
