@@ -15,11 +15,11 @@
    set in your MH configuration.
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../zotnet/mf.h"
-#include "../zotnet/tws.h"
-#include "../zotnet/mts.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <zotnet/mf.h>
+#include <zotnet/tws.h>
+#include <zotnet/mts.h>
 #include <signal.h>
 
 #define	ADDROK	0		/* okay to use post to deliver message */
