@@ -5,18 +5,18 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 static struct swit switches[] = {
-#define	INTRSW	0
-    "interactive", 0,
-#define	NINTRSW	1
-    "nointeractive", 0,
-#define VERSIONSW 2
-    "version", 0,
-#define	HELPSW	3
-    "help", 4,
-    NULL, 0
+#define	INTRSW            0
+    { "interactive", 0 },
+#define	NINTRSW           1
+    { "nointeractive", 0 },
+#define VERSIONSW         2
+    { "version", 0 },
+#define	HELPSW            3
+    { "help", 4 },
+    { NULL, 0 }
 };
 
 /*
@@ -45,7 +45,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -129,7 +129,7 @@ rmf (char *folder)
 
     switch (i = chdir (maildir = m_maildir (folder))) {
 	case OK: 
-	    if (access (".", 2) != NOTOK && access ("..", 2) != NOTOK)
+	    if (access (".", W_OK) != NOTOK && access ("..", W_OK) != NOTOK)
 		break;		/* fall otherwise */
 
 	case NOTOK: 
