@@ -5,10 +5,10 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/formatsbr.h"
-#include "../h/scansbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/formatsbr.h>
+#include <h/scansbr.h>
+#include <zotnet/tws/tws.h>
 #include <errno.h>
 
 static struct swit switches[] = {
@@ -41,42 +41,31 @@ static struct swit switches[] = {
 
 extern int errno;
 
-#ifdef LBL	/* global for sbr/formatsbr.c - yech! */
+/*
+ * global for sbr/formatsbr.c - yech!
+ */
+#ifdef LBL
 extern struct msgs *fmt_current_folder;	
 #endif
 
 /*
  * prototypes
  */
-void clear_screen(void);
+void clear_screen(void);  /* from termsbr.c */
 
 
 main (int argc, char **argv)
 {
-     int    clearflag = 0,
-	    hdrflag = 0,
-	    revflag = 0, 	/* used to be #ifdef BERK */
-	    width = 0,
-            msgp = 0,
-	    bits,		/* should match mp->msgstats[] type */
-	    ontty,
-	    state,
-            msgnum;
-    long    clock;
-    char   *cp,
-           *maildir,
-	   *file = NULL,
-           *folder = NULL,
-	   *form = NULL,
-	   *format = NULL,
-            buf[100],
-          **ap,
-          **argp,
-           *nfs,
-           *arguments[MAXARGS],
-           *msgs[MAXARGS];
+    int clearflag = 0, hdrflag = 0, ontty;
+    int state, width = 0, msgp = 0, msgnum;
+    int revflag = 0; 		/* used to be #ifdef BERK */
+    int bits;			/* should match mp->msgstats[] type */
+    long clock;
+    char *cp, *maildir, *file = NULL, *folder = NULL;
+    char *form = NULL, *format = NULL, buf[100], **ap;
+    char **argp, *nfs, *arguments[MAXARGS], *msgs[MAXARGS];
     struct msgs *mp;
-    FILE * in;
+    FILE *in;
 
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
@@ -92,7 +81,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -173,7 +162,10 @@ main (int argc, char **argv)
 	    adios (NULL, "\"msgs\" not allowed with -file");
 	if (folder)
 	    adios (NULL, "\"+folder\" not allowed with -file");
-	/* we've been asked to scan a maildrop file */
+
+	/*
+	 * we've been asked to scan a maildrop file
+	 */
 	if (strcmp (file, "-")) {
 	    in = fopen (file, "r");
 	    if (in == NULL)
@@ -194,7 +186,7 @@ main (int argc, char **argv)
 	m_unknown (in);
 	for (msgnum = 1; ; ++msgnum) {
 	    state = scan (in, msgnum, -1, nfs, width, 0, 0,
-		    hdrflag ? file : (char *)0, 0L, 1);
+		    hdrflag ? file : (char *) 0, 0L, 1);
 	    if (state != SCNMSG && state != SCNENC)
 		break;
 	}
