@@ -5,14 +5,14 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/formatsbr.h"
-#include "../h/scansbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/formatsbr.h>
+#include <h/scansbr.h>
+#include <zotnet/tws/tws.h>
 
 #ifdef _FSTDIO
-# define _ptr _p                /* Gag */
+# define _ptr _p                /* Gag    */
 # define _cnt _w                /* Wretch */
 #endif
 
@@ -33,26 +33,31 @@ static struct format *fmt;
 static struct format *fmt_top;
 #endif /* JLR */
 
-static struct comp *datecomp;		/* pntr to "date" comp */
-static struct comp *bodycomp;		/* pntr to "body" pseudo-comp 
-					 * (if referenced) */
-static int	ncomps = 0;		/* # of interesting components */
-static char	**compbuffers = 0; 	/* buffers for component text */
+static struct comp *datecomp;		/* pntr to "date" comp             */
+static struct comp *bodycomp;		/* pntr to "body" pseudo-comp      *
+					 * (if referenced)                 */
+static int ncomps = 0;			/* # of interesting components     */
+static char **compbuffers = 0; 		/* buffers for component text      */
 static struct comp **used_buf = 0;	/* stack for comp that use buffers */
 
-char    	*scanl = 0;		/* text of most recent scanline */
+char *scanl = 0;			/* text of most recent scanline    */
 
-static int  dat[5];			/* aux. data for format routine */
+static int dat[5];			/* aux. data for format routine    */
 
-#ifdef	RPATHS
-char   *unixline ();			/* info from UNIX From: line */
-#endif	/* RPATHS */
+#ifdef RPATHS
+char *unixline ();			/* info from UNIX From: line       */
+#endif
 
 #define FPUTS(buf) {\
 		if (mh_fputs(buf,scnout) == EOF)\
 		    adios (scnmsg, "write error on");\
 		}
 
+/*
+ * prototypes
+ */
+int sc_width (void);   /* from termsbr.c */
+
 
 int
 scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
@@ -71,7 +76,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
     static int rlwidth, slwidth;
 
     /* first-time only initialization */
-    if (scanl == NULL) {
+    if (!scanl) {
 	int	bigwid;
 
 	if (width == 0) {
