@@ -5,128 +5,108 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <errno.h>
 #include <signal.h>
 
-#ifndef	TMA
+#ifndef TMA
 # define TMAminc(a) (a)
-#else	/* TMA */
+#else
 # define TMAminc(a)  0
-#endif	/* TMA */
+#endif
 
-#ifdef	MIME
+#ifdef MIME
 # define MIMEminc(a) (a)
 #else
 # define MIMEminc(a)  0
 #endif
 
 static struct swit switches[] = {
-#define	ALIASW	0
-    "alias aliasfile", 0,
-
-#define	DEBUGSW	1
-    "debug", -5,
-
-#define	DRAFTSW	2
-    "draft", 0,
-
-#define	DFOLDSW	3
-    "draftfolder +folder", 6,
-#define	DMSGSW	4
-    "draftmessage msg", 6,
-#define	NDFLDSW	5
-    "nodraftfolder", 0,
-
-#define	ENCRSW	6
-    "encrypt", TMAminc (-7),
-#define	NENCRSW	7
-    "noencrypt", TMAminc (-9),
-
-#define	FILTSW	8
-    "filter filterfile", 0,
-#define	NFILTSW	9
-    "nofilter", 0,
-
-#define	FRMTSW	10
-    "format", 0,
-#define	NFRMTSW	11
-    "noformat", 0,
-
-#define	FORWSW	12
-    "forward", 0,
-#define	NFORWSW	13
-    "noforward", 0,
-
-#define	MIMESW	14
-    "mime", MIMEminc(-4),
-#define	NMIMESW	15
-    "nomime", MIMEminc(-6),
-
-#define	MSGDSW	16
-    "msgid", 0,
-#define	NMSGDSW	17
-    "nomsgid", 0,
-
-#define	PUSHSW	18
-    "push", 0,
-#define	NPUSHSW	19
-    "nopush", 0,
-
-#define	SPLITSW	20
-    "split seconds", MIMEminc(-5),
-
-#define	UNIQSW	21
-    "unique", -6,
-#define	NUNIQSW	22
-    "nounique", -8,
-
-#define	VERBSW	23
-    "verbose", 0,
-#define	NVERBSW	24
-    "noverbose", 0,
-
-#define	WATCSW	25
-    "watch", 0,
-#define	NWATCSW	26
-    "nowatch", 0,
-
-#define	WIDTHSW	27
-    "width columns", 0,
-
-#define VERSIONSW 28
-    "version", 0,
-#define	HELPSW	29
-    "help", 4,
-
-#define	MAILSW	30
-    "mail", -4,
-#define	SAMLSW	31
-    "saml", -4,
-#define	SENDSW	32
-    "send", -4,
-#define	SOMLSW	33
-    "soml", -4,
-
-#define	CLIESW	34
-    "client host", -6,
-#define	SERVSW	35
-    "server host", -6,
-#define	SNOOPSW	36
-    "snoop", -5,
-
-    NULL, 0
+#define	ALIASW                 0
+    { "alias aliasfile", 0 },
+#define	DEBUGSW                1
+    { "debug", -5 },
+#define	DRAFTSW                2
+    { "draft", 0 },
+#define	DFOLDSW                3
+    { "draftfolder +folder", 6 },
+#define	DMSGSW                 4
+    { "draftmessage msg", 6 },
+#define	NDFLDSW                5
+    { "nodraftfolder", 0 },
+#define	ENCRSW                 6
+    { "encrypt", TMAminc (-7) },
+#define	NENCRSW                7
+    { "noencrypt", TMAminc (-9) },
+#define	FILTSW                 8
+    { "filter filterfile", 0 },
+#define	NFILTSW                9
+    { "nofilter", 0 },
+#define	FRMTSW                10
+    { "format", 0 },
+#define	NFRMTSW               11
+    { "noformat", 0 },
+#define	FORWSW                12
+    { "forward", 0 },
+#define	NFORWSW               13
+    { "noforward", 0 },
+#define	MIMESW                14
+    { "mime", MIMEminc(-4) },
+#define	NMIMESW               15
+    { "nomime", MIMEminc(-6) },
+#define	MSGDSW                16
+    { "msgid", 0 },
+#define	NMSGDSW               17
+    { "nomsgid", 0 },
+#define	PUSHSW                18
+    { "push", 0 },
+#define	NPUSHSW               19
+    { "nopush", 0 },
+#define	SPLITSW               20
+    { "split seconds", MIMEminc(-5) },
+#define	UNIQSW                21
+    { "unique", -6 },
+#define	NUNIQSW               22
+    { "nounique", -8 },
+#define	VERBSW                23
+    { "verbose", 0 },
+#define	NVERBSW               24
+    { "noverbose", 0 },
+#define	WATCSW                25
+    { "watch", 0 },
+#define	NWATCSW               26
+    { "nowatch", 0 },
+#define	WIDTHSW               27
+    { "width columns", 0 },
+#define VERSIONSW             28
+    { "version", 0 },
+#define	HELPSW                29
+    { "help", 4 },
+#define	MAILSW                30
+    { "mail", -4 },
+#define	SAMLSW                31
+    { "saml", -4 },
+#define	SENDSW                32
+    { "send", -4 },
+#define	SOMLSW                33
+    { "soml", -4 },
+#define	CLIESW                34
+    { "client host", -6 },
+#define	SERVSW                35
+    { "server host", -6 },
+#define	SNOOPSW               36
+    { "snoop", -5 },
+    { NULL, 0 }
 };
 
 static struct swit anyl[] = {
-#define	NOSW	0
-    "no", 0,
-#define	YESW	1
-    "yes", 0,
-#define	LISTDSW	2
-    "list", 0,
-
-    NULL, 0
+#define	NOSW     0
+    { "no", 0 },
+#define	YESW     1
+    { "yes", 0 },
+#define	LISTDSW  2
+    { "list", 0 },
+    { NULL, 0 }
 };
 
 extern int debugsw;		/* from sendsbr.c */
@@ -155,7 +135,7 @@ main (int argc, char **argv)
     struct msgs *mp;
     struct stat st;
 #ifdef	UCI
-    FILE   *fp;
+    FILE *fp;
 #endif	/* UCI */
 
 #ifdef LOCALE
@@ -174,7 +154,7 @@ main (int argc, char **argv)
     vec[vecp++] = "-library";
     vec[vecp++] = getcpy (m_maildir (""));
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
