@@ -9,11 +9,11 @@
 
 /* Include files glommed from post.c */
 
-#include "../h/mh.h"
-#include "../h/addrsbr.h"
-#include "../h/aliasbr.h"
-#include "../h/dropsbr.h"
-#include "../zotnet/tws.h"
+#include <h/mh.h>
+#include <h/addrsbr.h>
+#include <h/aliasbr.h>
+#include <h/dropsbr.h>
+#include <zotnet/tws.h>
 
 #ifndef MMDFMTS
 # include <ctype.h>
@@ -22,21 +22,20 @@
 # include <stdio.h>
 # include <sys/types.h>
 #else  MMDFMTS
-# include "../mts/mmdf/util.h"
-# include "../mts/mmdf/mmdf.h"
+# include <mts/mmdf/util.h>
+# include <mts/mmdf/mmdf.h>
 #endif MMDFMTS
 
-#include "../zotnet/mts.h"
+#include <zotnet/mts.h>
 
 #ifdef MHMTS
 # include <sys/ioctl.h>
-# include <sys/stat.h>
 #endif MHMTS
 
 #ifdef SENDMTS
-# include "../mts/sendmail/smail.h"
+# include <mts/sendmail/smail.h>
 # undef  MF
-#endif  SENDMTS
+#endif
 
 #include <signal.h>
 
