@@ -5,11 +5,15 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
+#include <h/mh.h>
+#include <h/signals.h>
 #include <setjmp.h>
 #include <signal.h>
 
+#ifdef MIME
+# include <h/mhn.h>
+#endif
+
 int debugsw = 0;		/* global */
 int forwsw = 1;
 int inplace = 0;
@@ -67,7 +71,6 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st)
 
 
 #ifdef MIME
-#include "../h/mhn.h"
 
 static int
 sendaux (char **vec, int vecp, char *drft, struct stat *st)
