@@ -24,11 +24,11 @@
  *  or "mts mmdf1" set in your MH configuration.
  */
 
-#include "../h/mh.h"
-#include "../h/dropsbr.h"
-#include "../h/rcvmail.h"
-#include "../zotnet/tws/tws.h"
-#include "../zotnet/mts/mts.h"
+#include <h/mh.h>
+#include <h/dropsbr.h>
+#include <h/rcvmail.h>
+#include <zotnet/tws/tws.h>
+#include <zotnet/mts/mts.h>
 #include <pwd.h>
 #include <signal.h>
 #include <sys/ioctl.h>
@@ -37,15 +37,10 @@
 #ifdef MSGID
 # undef DBM		/* used by ndbm.h */
 # include <ndbm.h>
-# include <stdio.h>
-# include <sys/types.h>
 # include <sys/file.h>
 # ifdef SYS5
 #  include <fcntl.h>
 # endif
-# ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-# endif
 # if defined(LOCKF) && !defined(F_ULOCK)
 #  include <sys/fcntl.h>
 # endif  /* LOCKF */
@@ -83,11 +78,11 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
-static int  debug = 0;
-static int  globbed = 0;
-static int  parsed = 0;
-static int  utmped = 0;
-static int  verbose = 0;
+static int debug = 0;
+static int globbed = 0;
+static int parsed = 0;
+static int utmped = 0;
+static int verbose = 0;
 
 static char *addr = NULL;
 static char *user = NULL;
@@ -106,43 +101,41 @@ struct tws *now;
 
 static jmp_buf myctx;
 
-struct pair {
-    char   *p_name;
-    char   *p_value;
+/* flags for pair->p_flags */
+#define	P_NIL  0x00
+#define	P_ADR  0x01
+#define	P_HID  0x02
+#define	P_CHK  0x04
 
-    char    p_flags;
-#define	P_NIL	0x00
-#define	P_ADR	0x01
-#define	P_HID	0x02
-#define	P_CHK	0x04
+struct pair {
+    char *p_name;
+    char *p_value;
+    char  p_flags;
 };
 
-static struct pair  hdrs[NVEC + 1] = {
-    "source", NULL, P_HID,
-    "addr", NULL, P_HID,
-
-    "Return-Path", NULL, P_ADR,
-    "Reply-To", NULL, P_ADR,
-    "From", NULL, P_ADR,
-    "Sender", NULL, P_ADR,
-    "To", NULL, P_ADR,
-    "cc", NULL, P_ADR,
-    "Resent-Reply-To", NULL, P_ADR,
-    "Resent-From", NULL, P_ADR,
-    "Resent-Sender", NULL, P_ADR,
-    "Resent-To", NULL, P_ADR,
-    "Resent-cc", NULL, P_ADR,
-
+static struct pair hdrs[NVEC + 1] = {
+    { "source",          NULL, P_HID },
+    { "addr",            NULL, P_HID },
+    { "Return-Path",     NULL, P_ADR },
+    { "Reply-To",        NULL, P_ADR },
+    { "From",            NULL, P_ADR },
+    { "Sender",          NULL, P_ADR },
+    { "To",              NULL, P_ADR },
+    { "cc",              NULL, P_ADR },
+    { "Resent-Reply-To", NULL, P_ADR },
+    { "Resent-From",     NULL, P_ADR },
+    { "Resent-Sender",   NULL, P_ADR },
+    { "Resent-To",       NULL, P_ADR },
+    { "Resent-cc",       NULL, P_ADR },
     NULL
 };
 
-static struct pair  vars[] = {
-    "sender", NULL, P_NIL,
-    "address", NULL, P_NIL,
-    "size", NULL, P_NIL,
-    "reply-to", NULL, P_CHK,
-    "info", NULL, P_NIL,
-
+static struct pair vars[] = {
+    { "sender",   NULL, P_NIL },
+    { "address",  NULL, P_NIL },
+    { "size",     NULL, P_NIL },
+    { "reply-to", NULL, P_CHK },
+    { "info",     NULL, P_NIL },
     NULL
 };
 
@@ -187,7 +180,7 @@ main (int argc, char **argv)
     m_foil (NULL);
     mts_init (invo_name);
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -303,7 +296,7 @@ main (int argc, char **argv)
 	if ((fd = copyfile (fileno (stdin), file = tmpfil, 1)) == NOTOK)
 	    adios (NULL, "unable to create temporary file");
 	if (debug)
-	    fprintf (stderr, "temporary file \"%s\" selected\n", tmpfil);
+	    fprintf (stderr, "temporary file=\"%s\"\n", tmpfil);
 	else
 	    unlink (tmpfil);
    	if ((fp = fdopen (fd, "r+")) == NULL)
@@ -331,12 +324,16 @@ main (int argc, char **argv)
     sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
 
     if (debug) {
-	fprintf (stderr, "addr=\"%s\" user=\"%s\" info=\"%s\" file=\"%s\"\n",
-		addr, user, info, file);
-	fprintf (stderr, "sender=\"%s\" mbox=\"%s\" home=\"%s\" from=\"%s\"\n",
-		sender, mbox, home, from);
-	fprintf (stderr, "ddate=\"%s\" now=%02d:%02d\n",
-		ddate, now->tw_hour, now->tw_min);
+	fprintf (stderr, "addr=\"%s\"\n", addr);
+	fprintf (stderr, "user=\"%s\"\n", user);
+	fprintf (stderr, "info=\"%s\"\n", info);
+	fprintf (stderr, "file=\"%s\"\n", file);
+	fprintf (stderr, "sender=\"%s\"\n", sender);
+	fprintf (stderr, "mbox=\"%s\"\n", mbox);
+	fprintf (stderr, "home=\"%s\"\n", home);
+	fprintf (stderr, "from=\"%s\"\n", from);
+	fprintf (stderr, "ddate=\"%s\"\n", ddate);
+	fprintf (stderr, "now=%02d:%02d\n\n", now->tw_hour, now->tw_min);
     }
 
     done (localmail (fd, from, mdlvr) != NOTOK ? RCV_MOK : RCV_MBX);
@@ -497,7 +494,23 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 		status = usr_pipe (fd, tmpbuf, "/bin/sh", vec + 2);
 		break;
 
+	    case '+':
+	    dofolder:
+		if (*string == '+')
+		    strcpy(tmpbuf, string);
+		else
+		    sprintf(tmpbuf, "+%s", string);
+		vec[2] = "rcvstore";
+		vec[3] = tmpbuf;
+		vec[4] = NULL;
+		if (verbose)
+		    printf("%s %s", rcvstoreproc, vec[3]);
+		status = usr_pipe(fd, "rcvstore", rcvstoreproc, vec + 2);
+		break;
+
 	    case 'f': 
+		if (uleq(action, "folder"))
+		    goto dofolder;
 		if (!uleq (action, "file"))
 		    continue;	/* else fall */
 	    case '>': 
@@ -662,7 +675,7 @@ parse (int fd)
     if (debug)
 	for (p = hdrs; p->p_name; p++)
 	    fprintf (stderr, "hdrs[%d]: name=\"%s\" value=\"%s\"\n",
-		p - hdrs, p->p_name, p->p_value);
+		p - hdrs, p->p_name, p->p_value ? p->p_value : "");
 
     return OK;
 }
@@ -850,10 +863,10 @@ usr_hook (int fd, char *mailbox)
 
     vecp = 1;
     sprintf (receive, "%s/.mh_receive", pw->pw_dir);
-    switch (access (receive, 01)) {
+    switch (access (receive, X_OK)) {
 	case NOTOK: 
 	    sprintf (receive, "%s/bin/rcvmail", pw->pw_dir);
-	    if (access (receive, 01) == NOTOK) {
+	    if (access (receive, X_OK) == NOTOK) {
 		unlink (tmpfil);
 		if (verbose) {
 		    printf ("\tnot present\n");
