@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <zotnet/tws/tws.h>
 
 #if defined(SYS5) && defined(AUX)
 # define u_short ushort
@@ -88,7 +88,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 	    case AMBIGSW:
