@@ -1,5 +1,5 @@
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 /*
  *
@@ -47,13 +47,13 @@
 #include <pwd.h>
 
 #ifndef	SPOP
-# include "../h/addrsbr.h"
+# include <h/addrsbr.h>
 #endif
 
-#include "../h/dropsbr.h"
-#include "../zotnet/bboards/bboards.h"
-#include "../zotnet/tws/tws.h"
-#include "../zotnet/mts/mts.h"
+#include <h/dropsbr.h>
+#include <zotnet/bboards/bboards.h>
+#include <zotnet/tws/tws.h>
+#include <zotnet/mts/mts.h>
 
 #ifndef	SYS5
 # include <sysexits.h>
@@ -67,11 +67,11 @@
 # define EX_OSFILE	1
 # define EX_UNAVAILABLE	1
 # define EX_USAGE	1
-#endif	SYS5
+#endif
 
-#ifdef	DISTRIBUTE
-# include "../mts/sendmail/smail.h"
-#endif	DISTRIBUTE
+#ifdef DISTRIBUTE
+# include <mts/sendmail/smail.h>
+#endif
 
 #define	NBB	100
 
