@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
@@ -44,15 +44,17 @@ extern short ospeed;
 extern char PC;
 #endif
 
-static int  HC = 0;
+static long speedcode;
 
-static int  initLI = 0;
-static int  LI = 40;
-static int  initCO = 0;
-static int  CO = 80;
-static char *CL = NULL;
-static char *SE = NULL;
-static char *SO = NULL;
+static int initLI = 0;
+static int initCO = 0;
+
+static int HC = 0;       /* are we on a hardcopy terminal?        */
+static int LI = 40;      /* number of lines                       */
+static int CO = 80;      /* number of colums                      */
+static char *CL = NULL;  /* termcap string to clear screen        */
+static char *SE = NULL;  /* termcap string to end standout mode   */
+static char *SO = NULL;  /* termcap string to begin standout mode */
 
 static char termcap[TXTSIZ];
 
@@ -60,8 +62,12 @@ static char termcap[TXTSIZ];
 static
 read_termcap(void)
 {
-    register char *bp, *term;
-    char *cp, myterm[TXTSIZ];
+    char *bp, *cp;
+    char *term;
+
+#ifndef TGETENT_ACCEPTS_NULL
+    char termbuf[TXTSIZ];
+#endif
 
 #ifdef HAVE_TERMIOS_H
     struct termios tio;
@@ -78,16 +84,27 @@ read_termcap(void)
     if (inited++)
 	return;
 
-    if ((term = getenv ("TERM")) == NULL || tgetent (myterm, term) <= OK)
+    if (!(term = getenv ("TERM")))
 	return;
 
+/*
+ * If possible, we let tgetent allocate its own termcap buffer
+ */
+#ifdef TGETENT_ACCEPTS_NULL
+    if (tgetent (NULL, term) <= 0)
+	return
+#else
+    if (tgetent (termbuf, term) <= 0)
+	return;
+#endif
+
 #ifdef HAVE_TERMIOS_H
-    ospeed = cfgetospeed(&tio);
+    speedcode = cfgetospeed(&tio);
 #else
 # ifdef HAVE_TERMIO_H
-    ospeed = ioctl(fileno(stdout), TCGETA, &tio) != NOTOK ? tio.c_cflag & CBAUD : 0;
+    speedcode = ioctl(fileno(stdout), TCGETA, &tio) != NOTOK ? tio.c_cflag & CBAUD : 0;
 # else
-    ospeed = ioctl(fileno(stdout), TIOCGETP, (char *) &tio) != NOTOK ? tio.sg_ospeed : 0;
+    speedcode = ioctl(fileno(stdout), TIOCGETP, (char *) &tio) != NOTOK ? tio.sg_ospeed : 0;
 # endif
 #endif
 
@@ -157,11 +174,11 @@ clear_screen (void)
 {
     read_termcap ();
 
-    if (CL && ospeed)
+    if (CL && speedcode)
 	tputs (CL, LI, outc);
     else {
 	printf ("\f");
-	if (ospeed)
+	if (speedcode)
 	    printf ("\200");
     }
 
@@ -169,24 +186,37 @@ clear_screen (void)
 }
 
 
+/*
+ * print in standout mode
+ */
 int
-SOprintf (char *fmt, char *a, char *b, char *c, char *d, char *e, char *f)
+SOprintf (char *fmt, ...)
 {
+    va_list ap;
+
     read_termcap ();
-    if (SO == NULL || SE == NULL)
+    if (!(SO && SE))
 	return NOTOK;
 
     tputs (SO, 1, outc);
-    printf (fmt, a, b, c, d, e, f);
+
+    va_start(ap, fmt);
+    vprintf (fmt, ap);
+    va_end(ap);
+
     tputs (SE, 1, outc);
 
     return OK;
 }
 
+/*
+ * Is this a hardcopy terminal?
+ */
+
 int
 sc_hardcopy(void)
 {
     read_termcap();
-
     return HC;
 }
+
