@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/nmh.h"
+#include <h/nmh.h>
 #include <pwd.h>
 
 #ifndef	NSIG
