@@ -20,9 +20,9 @@
 	- kill a child that's run away (the child sets up a process group)
  */
 
-#include "../h/mh.h"
-#include "../zotnet/mf.h"
-#include "../zotnet/mts.h"
+#include <h/mh.h>
+#include <zotnet/mf.h>
+#include <zotnet/mts.h>
 #include <pwd.h>
 #include <signal.h>
 #include <sys/ioctl.h>
@@ -49,7 +49,7 @@ static char myaddr[BUFSIZ] = "";
 static char mystat[BUFSIZ] = "";
 static char myuser[BUFSIZ] = "";
 
-int	sigser ();
+int sigser ();
 
 
 main (int argc, char **argv)
@@ -132,7 +132,7 @@ main (int argc, char **argv)
     strcpy (myhome, pw->pw_dir);
     sprintf (mystat, ".%s_%d", invo_name, pw->pw_uid);
 
-    if (access (slocalproc, 1) == NOTOK)
+    if (access (slocalproc, X_OK) == NOTOK)
 	adios (slocalproc, "unable to execute");
 
     closefds (fileno (stderr) + 1);
