@@ -5,7 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
+
 
 main (int argc, char **argv)
 {
