@@ -5,7 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
+
 
 int
 what_now (char *ed, int nedit, int use, char *file, char *altmsg, int dist,
