@@ -5,9 +5,13 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <signal.h>
 
+#ifdef MIME
+#include <h/mhn.h>
+#endif
+
 #ifndef	MIME
 # define MIMEminc(a) (a)
 #else
@@ -15,41 +19,41 @@
 #endif
 
 static struct swit whatnowswitches[] = {
-#define	DFOLDSW                   0
+#define	DFOLDSW                 0
     { "draftfolder +folder", 0 },
-#define	DMSGSW                    1
+#define	DMSGSW                  1
     { "draftmessage msg", 0 },
-#define	NDFLDSW                   2
+#define	NDFLDSW                 2
     { "nodraftfolder", 0 },
-#define	EDITRSW                   3
+#define	EDITRSW                 3
     { "editor editor", 0 },
-#define	NEDITSW                   4
+#define	NEDITSW                 4
     { "noedit", 0 },
-#define	PRMPTSW                   5
+#define	PRMPTSW                 5
     { "prompt string", 4 },
-#define VERSIONSW                 6
+#define VERSIONSW               6
     { "version", 0 },
-#define	HELPSW                    7
+#define	HELPSW                  7
     { "help", 4 },
     { NULL, 0 }
 };
 
 static struct swit aleqs[] = {
-#define	DISPSW                           0
+#define	DISPSW                         0
     { "display [<switches>]", 0 },
-#define	EDITSW                           1
+#define	EDITSW                         1
     { "edit [<editor> <switches>]", 0 },
-#define	LISTSW                           2
+#define	LISTSW                         2
     { "list [<switches>]", 0 },
-#define	PUSHSW                           3
+#define	PUSHSW                         3
     { "push [<switches>]", 0 },
-#define	QUITSW                           4
+#define	QUITSW                         4
     { "quit [-delete]", 0 },
-#define	REFILEOPT                        5
+#define	REFILEOPT                      5
     { "refile [<switches>] +folder", 0 },
-#define	SENDSW                           6
+#define	SENDSW                         6
     { "send [<switches>]", 0 },
-#define	WHOMSW                           7
+#define	WHOMSW                         7
     { "whom [<switches>]", 0 },
     { NULL, 0 }
 };
@@ -94,7 +98,7 @@ WhatNow (int argc, char **argv)
     argp = arguments;
 
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, whatnowswitches)) {
 		case AMBIGSW: 
@@ -358,7 +362,7 @@ editfile (char **ed, char **arg, char *file, int use,
 		    && (!mp->msgflags & READONLY)
 		    && (slinked
 		           ? lstat (linkpath, &st) != NOTOK
-				&& (st.st_mode & S_IFMT) == S_IFREG
+				&& S_ISREG(st.st_mode)
 				&& copyf (linkpath, altpath) == NOTOK
 		           : stat (linkpath, &st) != NOTOK
 				&& st.st_nlink == 1
@@ -479,7 +483,6 @@ sendfile (char **arg, char *file, int pushsw)
 
 
 #ifdef MIME
-#include "../h/mhn.h"
 
 static int
 mhnfile (char *msgnam)
