@@ -5,41 +5,35 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <signal.h>
 
 static struct swit switches[] = {
-#define	ALIASW	0
-    "alias aliasfile", 0,
-
-#define	CHKSW	1
-    "check", 0,
-#define	NOCHKSW	2
-    "nocheck", 0,
-
-#define	DRAFTSW	3
-    "draft", 0,
-
-#define	DFOLDSW	4
-    "draftfolder +folder", 6,
-#define	DMSGSW	5
-    "draftmessage msg", 6,
-#define	NDFLDSW	6
-    "nodraftfolder", 0,
-
-#define VERSIONSW 7
-    "version", 0,
-#define	HELPSW	8
-    "help", 4,
-
-#define	CLIESW	9
-    "client host", -6,
-#define	SERVSW	10
-    "server host", -6,
-#define	SNOOPSW	11
-    "snoop", -5,
-
-    NULL, 0
+#define	ALIASW              0
+    { "alias aliasfile", 0 },
+#define	CHKSW               1
+    { "check", 0 },
+#define	NOCHKSW             2
+    { "nocheck", 0 },
+#define	DRAFTSW             3
+    { "draft", 0 },
+#define	DFOLDSW             4
+    { "draftfolder +folder", 6 },
+#define	DMSGSW              5
+    { "draftmessage msg", 6 },
+#define	NDFLDSW             6
+    { "nodraftfolder", 0 },
+#define VERSIONSW           7
+    { "version", 0 },
+#define	HELPSW              8
+    { "help", 4 },
+#define	CLIESW              9
+    { "client host", -6 },
+#define	SERVSW             10
+    { "server host", -6 },
+#define	SNOOPSW            11
+    { "snoop", -5 },
+    { NULL, 0 }
 };
 
 
