@@ -13,9 +13,9 @@
  * windows should be, and where all the windows should be.
  */
 
-#include "../h/mh.h"
-#include "../h/signals.h"
-#include "../h/vmhsbr.h"
+#include <h/mh.h>
+#include <h/signals.h>
+#include <h/vmhsbr.h>
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
@@ -31,78 +31,70 @@
 #define	SZ(a) (sizeof a / sizeof a[0])
 
 static struct swit switches[] = {
-#define	PRMPTSW	0
-    "prompt string", 6,
-#define	PROGSW	1
-    "vmhproc program", 7,
-#define	NPROGSW	2
-    "novmhproc", 9,
-#define VERSIONSW 3
-    "version", 0,
-#define	HELPSW	4
-    "help", 4,
-    NULL, NULL
+#define	PRMPTSW            0
+    { "prompt string", 6 },
+#define	PROGSW             1
+    { "vmhproc program", 7 },
+#define	NPROGSW            2
+    { "novmhproc", 9 },
+#define VERSIONSW          3
+    { "version", 0 },
+#define	HELPSW             4
+    { "help", 4 },
+    { NULL, NULL }
 };
 					/* PEERS */
-static int  PEERpid = NOTOK;
+static int PEERpid = NOTOK;
 
-static  jmp_buf PEERctx;
+static jmp_buf PEERctx;
 
 
 					/* WINDOWS */
 static int dfd = NOTOK;
-
 static int twd = NOTOK;
-
 static char *myprompt = "(%s) ";
 
 struct line {
-    int     l_no;
-    char   *l_buf;
+    int l_no;
+    char *l_buf;
     struct line *l_prev;
     struct line *l_next;
 };
 
-typedef struct {
-    int	    w_fd;
-
-    int	    w_flags;
 #define	W_NULL	0x00
 #define	W_CMND	0x01
 #define	W_FAKE	0x02
 #define	W_EBAR	0x04
 
-    int	    w_wd;
-
+typedef struct {
+    int	w_fd;
+    int	w_flags;
+    int	w_wd;
     struct wstate w_ws;
-
-    char   *w_eb;
-    int	    w_ebloc;
-    int	    w_ebsize;
-
-    int	    w_cbase;
-    int	    w_height;
-    int	    w_cheight;
-    int	    w_width;
-    int	    w_cwidth;
-
+    char *w_eb;
+    int	w_ebloc;
+    int	w_ebsize;
+    int	w_cbase;
+    int	w_height;
+    int	w_cheight;
+    int	w_width;
+    int	w_cwidth;
     struct line *w_head;
     struct line *w_top;
     struct line *w_bottom;
     struct line *w_tail;
-
-    char   w_buffer[BUFSIZ];
-    int	   w_bufpos;
-}	WINDOW;
+    char w_buffer[BUFSIZ];
+    int	w_bufpos;
+} WINDOW;
 
 
-static  WINDOW *Scan;
-static  WINDOW *Status;
-static  WINDOW *Display;
-static  WINDOW *Command;
+static WINDOW *Scan;
+static WINDOW *Status;
+static WINDOW *Display;
+static WINDOW *Command;
 
 #define	NWIN 4
-static	int numwins;
+static int numwins;
 WINDOW *windows[NWIN + 1];
 
 WINDOW *WINnew ();
@@ -129,15 +121,18 @@ static struct tchars tc;
 # endif
 #endif
 
-#define	WERASC	ltc.t_werasc
+#define	WERASC ltc.t_werasc
 static struct ltchars ltc;
 
+extern int errno;
+
 int ALRMser (), PIPEser (), SIGser ();
 int ADJser (), REFser ();
 
-extern int  errno;
-
-void adorn();
+/*
+ * static prototypes
+ */
+static void adorn(char *, char *, ...);
 
 
 main (int argc, char **argv)
@@ -159,7 +154,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++)
+    while ((cp = *argp++))
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -1386,10 +1381,7 @@ DisplayVector (struct iovec *iov, int n)
     }
 
     DisplayStatus (dfd, cp);
-
     free (cp);
-
     sleep (PAUSE);
-
     RemoveStatus (dfd);
 }
