@@ -5,30 +5,34 @@
  * $Id$
  */
 
-#include "../../h/nmh.h"
+#include <h/nmh.h>
 
 #ifdef MMDFONLY
-# include "util.h"
-# include "mmdf.h"
-# include "strings.h"
+# include <util.h>
+# include <mmdf.h>
+# include <strings.h>
 #endif	/* MMDFONLY */
 
-#include <ctype.h>
 #include <pwd.h>
 #include <grp.h>
-#include <stdio.h>
-#include <sys/stat.h>
+#include <bboards.h>
 
-#include "bboards.h"
+#ifdef HAVE_CRYPT_H
+# include <crypt.h>
+#endif
+
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #ifndef	MMDFONLY
-#define	NOTOK	(-1)
-#define	OK	0
-#endif	/* not MMDFONLY */
+# define NOTOK	(-1)
+# define OK	0
+#endif
 
-#define	MaxBBAka	100
-#define	MaxBBLdr	100
-#define	MaxBBDist	100
+#define	MaxBBAka  100
+#define	MaxBBLdr  100
+#define	MaxBBDist 100
 
 #define	NCOLON	9		/* currently 10 fields per entry */
 
@@ -70,14 +74,6 @@ static char BBErrors[BUFSIZ];
 
 #ifdef	MMDFONLY
 extern LLog *logptr;
-#endif	/* MMDFONLY */
-
-#ifdef HAVE_CRYPT_H
-# include <crypt.h>
-#endif
-
-#ifdef HAVE_UNISTD_H
-# include <unistd.h>
 #endif
 
 #ifdef UCL
