@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "mf.h"
+#include <mf.h>
 #include <ctype.h>
 #include <stdio.h>
 
