@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../../h/mh.h"
+#include <h/mh.h>
 
 /*
  * ENCLOSES REST OF THE FILE
@@ -17,7 +17,7 @@
 # define u_long  ulong
 #endif
 
-#include "mts.h"
+#include <mts.h>
 #include <errno.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -340,14 +340,8 @@ inet (struct hostent *hp, int net)
 
 /* taken from ISODE's compat/internet.c */
 
-#ifndef	DG
-u_long	inet_addr ();
-#else
-struct in_addr inet_addr ();
-#endif
-
-
 static char *empty = NULL;
+
 #ifdef h_addr
 static char *addrs[2] = { NULL };
 #endif
