@@ -5,9 +5,11 @@
  * $Id$
  */
 
-#include "../../h/mh.h"
+#include <h/mh.h>
 
 /*
+ * (not true anymore)
+ *
  * compile-time priority:
  *	LOCKF	use if defined
  *	FCNTL	use if SYS5  defined and LOCKF not defined
@@ -19,14 +21,13 @@
 #endif
 
 #ifndef	LOCKONLY
-# include "mts.h"
+# include <mts.h>
 #else	/* LOCKONLY */
-# include "strings.h"
 # ifdef MMDFONLY
-#  include "mmdfonly.h"
-#  include "mts.h"
+#  include <mmdfonly.h>
+#  include <mts.h>
 # else	/* not MMDFONLY */
-#  include "lockonly.h"
+#  include <lockonly.h>
 # endif	/* not MMDFONLY */
 #endif	/* LOCKONLY */
 
@@ -41,10 +42,6 @@
 # include <sys/file.h>
 #endif
 
-#if defined(_AIX) || defined(AUX)
-# include <sys/file.h>
-#endif
-
 #ifdef SYS5
 # define u_short ushort
 # define u_long ulong
@@ -183,19 +180,11 @@ lockname (char *curlock, char *tmplock, char *file, int dev, int ino)
     }
 }
 
-/* if we have any time of locking defined */
+/*
+ * if we have any type of kernel locking defined
+ */
 
 #if defined(FLOCK) || defined(LOCKF) || defined(FCNTL)
-# if defined(BSD42) || defined(SVR4)
-#  include <sys/file.h>
-#  if defined(SUN40) || defined(SVR4)
-#   include <sys/fcntl.h>
-#  endif
-# else 
-#  ifdef FCNTL
-#   include <fcntl.h>
-#  endif
-# endif
 
 static int
 f_lkopen (char *file, int access)
