@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../../h/nmh.h"
+#include <h/nmh.h>
 
 #define nmhetcdir(file) NMHETCDIR#file
 
@@ -16,7 +16,7 @@
 
 #include <ctype.h>
 #include <stdio.h>
-#include "mts.h"
+#include <mts.h>
 
 #ifdef NETWORK
 # ifdef SOCKETS
@@ -152,69 +152,69 @@ char *NoShell = "";
  * mts.conf in the nmh etc directory.
  */
 
-static  struct bind {
-    char   *keyword;
-    char  **value;
-}       binds[] = {
-    "localname", &localname,
-    "localdomain", &localdomain,
-    "systemname", &systemname,
+struct bind {
+    char *keyword;
+    char **value;
+};
+
+static struct bind binds[] = {
+    { "localname", &localname },
+    { "localdomain", &localdomain },
+    { "systemname", &systemname },
 #ifdef MF
-    "uucpchan", &UUCPchan,
-#endif /* MF */
-    "mmdfldir", &mmdfldir,
-    "mmdflfil", &mmdflfil,
-    "uucpldir", &uucpldir,
-    "uucplfil", &uucplfil,
-    "mmdelim1", &mmdlm1,
-    "mmdelim2", &mmdlm2,
-    "mmailid", &mmailid,
-    "umincproc", &umincproc,
-    "lockstyle", &lkstyle,
-    "lockldir", &lockldir,
+    { "uucpchan", &UUCPchan },
+#endif
+    { "mmdfldir", &mmdfldir },
+    { "mmdflfil", &mmdflfil },
+    { "uucpldir", &uucpldir },
+    { "uucplfil", &uucplfil },
+    { "mmdelim1", &mmdlm1 },
+    { "mmdelim2", &mmdlm2 },
+    { "mmailid", &mmailid },
+    { "umincproc", &umincproc },
+    { "lockstyle", &lkstyle },
+    { "lockldir", &lockldir },
 
 #ifdef MHMTS
-    "mailqdir", &Mailqdir,
-    "tmailqdir", &TMailqdir,
-    "syscpy", &syscpy,
-    "overseer", &Overseer,
-    "mailer", &Mailer,
-    "fromtmp", &Fromtmp,
-    "msgtmp", &Msgtmp,
-    "errtmp", &Errtmp,
-    "tmpmode", &tmpmode,
-    "okhosts", &Okhosts,
-    "okdests", &Okdests,
-#endif /* MHMTS */
+    { "mailqdir", &Mailqdir },
+    { "tmailqdir", &TMailqdir },
+    { "syscpy", &syscpy },
+    { "overseer", &Overseer },
+    { "mailer", &Mailer },
+    { "fromtmp", &Fromtmp },
+    { "msgtmp", &Msgtmp },
+    { "errtmp", &Errtmp },
+    { "tmpmode", &tmpmode },
+    { "okhosts", &Okhosts },
+    { "okdests", &Okdests },
+#endif
 
 #ifdef MMDFMTS
 #endif /* MMDFMTS */
 
 #ifdef SENDMTS
-    "hostable", &hostable,
-    "sendmail", &sendmail,
-#endif /* SENDMTS */
+    { "hostable", &hostable },
+    { "sendmail", &sendmail },
+#endif
 
-    "clientname",  &clientname,
-    "servers", &servers,
-    "pophost", &pophost,
-
-    "bbdomain", &bb_domain,
+    { "clientname",  &clientname },
+    { "servers", &servers },
+    { "pophost", &pophost },
+    { "bbdomain", &bb_domain },
 
 #ifdef BPOP
-    "popbbhost", &popbbhost,
-    "popbbuser", &popbbuser,
-    "popbblist", &popbblist,
-#endif /* BPOP */
-#ifdef	NNTP
-    "nntphost", &popbbhost,
-#endif /* NNTP */
+    { "popbbhost", &popbbhost },
+    { "popbbuser", &popbbuser },
+    { "popbblist", &popbblist },
+#endif
 
-    "maildelivery", &maildelivery,
-
-    "everyone", &everyone,
-    "noshell", &NoShell,
+#ifdef NNTP
+    { "nntphost", &popbbhost },
+#endif
 
+    { "maildelivery", &maildelivery },
+    { "everyone", &everyone },
+    { "noshell", &NoShell },
     NULL
 };
 
