@@ -5,16 +5,8 @@
  * $Id$
  */
 
-#include "../../h/nmh.h"
-
-#include "tws.h"
-
-#ifdef INETONLY
-# include "strings.h"
-#endif	/* INETONLY */
-
-#include <stdio.h>
-#include <sys/types.h>
+#include <h/nmh.h>
+#include <tws.h>
 
 #if !defined(SYS5) && !defined(ZONEINFO)
 # include <sys/timeb.h>
@@ -32,7 +24,7 @@
 #endif
 
 #ifdef SYS5
-extern int  daylight;
+extern int daylight;
 extern long timezone;
 extern char *tzname[];
 #endif
@@ -45,69 +37,92 @@ extern char *tzname[];
 	(((y) % 4) ? 365 : (((y) % 100) ? 366 : (((y) % 400) ? 365 : 366)))
 
 char *tw_moty[] = {
-    "Jan", "Feb", "Mar", "Apr", "May", "Jun",
-    "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", NULL
+    "Jan",
+    "Feb",
+    "Mar",
+    "Apr",
+    "May",
+    "Jun",
+    "Jul",
+    "Aug",
+    "Sep",
+    "Oct",
+    "Nov",
+    "Dec",
+    NULL
 };
 
 char *tw_dotw[] = {
-    "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", NULL
+    "Sun",
+    "Mon",
+    "Tue",
+    "Wed",
+    "Thu",
+    "Fri",
+    "Sat",
+    NULL
 };
 
 char *tw_ldotw[] = {
-    "Sunday", "Monday", "Tuesday", "Wednesday",
-    "Thursday", "Friday", "Saturday", NULL
+    "Sunday",
+    "Monday",
+    "Tuesday",
+    "Wednesday",
+    "Thursday",
+    "Friday",
+    "Saturday",
+    NULL
 };
 
 
-static struct zone {
-    char   *std,
-           *dst;
-    int     shift;
-}                   zones[] = {
-			"GMT", "BST", 0,
-                        "EST", "EDT", -5,
-                        "CST", "CDT", -6,
-                        "MST", "MDT", -7,
-                        "PST", "PDT", -8,
-#ifdef	notdef	/* RFC1123 specifies do not use military TZs */
-                        "A", NULL, -1,
-                        "B", NULL, -2,
-                        "C", NULL, -3,
-                        "D", NULL, -4,
-                        "E", NULL, -5,
-                        "F", NULL, -6,
-                        "G", NULL, -7,
-                        "H", NULL, -8,
-                        "I", NULL, -9,
-                        "K", NULL, -10,
-                        "L", NULL, -11,
-                        "M", NULL, -12,
-                        "N", NULL, 1,
-#ifndef	HUJI
-                        "O", NULL, 2,
-#else	/* HUJI */
-			"JST", "JDT", 2,
-#endif	/* HUJI */
-                        "P", NULL, 3,
-                        "Q", NULL, 4,
-                        "R", NULL, 5,
-                        "S", NULL, 6,
-                        "T", NULL, 7,
-                        "U", NULL, 8,
-                        "V", NULL, 9,
-                        "W", NULL, 10,
-                        "X", NULL, 11,
-                        "Y", NULL, 12,
-#endif	/* notdef */
+struct zone {
+    char *std;
+    char *dst;
+    int shift;
+};
 
-                        NULL
+static struct zone zones[] = {
+    { "GMT", "BST", 0 },
+    { "EST", "EDT", -5 },
+    { "CST", "CDT", -6 },
+    { "MST", "MDT", -7 },
+    { "PST", "PDT", -8 },
+#if 0
+/* RFC1123 specifies do not use military TZs */
+    { "A", NULL, -1 },
+    { "B", NULL, -2 },
+    { "C", NULL, -3 },
+    { "D", NULL, -4 },
+    { "E", NULL, -5 },
+    { "F", NULL, -6 },
+    { "G", NULL, -7 },
+    { "H", NULL, -8 },
+    { "I", NULL, -9 },
+    { "K", NULL, -10 },
+    { "L", NULL, -11 },
+    { "M", NULL, -12 },
+    { "N", NULL, 1 },
+#ifndef	HUJI
+    { "O", NULL, 2 },
+#else
+    { "JST", "JDT", 2 },
+#endif
+    { "P", NULL, 3 },
+    { "Q", NULL, 4 },
+    { "R", NULL, 5 },
+    { "S", NULL, 6 },
+    { "T", NULL, 7 },
+    { "U", NULL, 8 },
+    { "V", NULL, 9 },
+    { "W", NULL, 10 },
+    { "X", NULL, 11 },
+    { "Y", NULL, 12 },
+#endif
+    NULL
 };
 
 #define CENTURY 1900
 
-long time();
-struct tm *localtime();
-
 
 char *
 dtimenow(void)
